@@ -356,7 +356,11 @@ findCurvesNew <- function(displacement, eccon, isInertial, min_height, draw, tit
 			startHStored[count] = startHStoredOld[i]
 			count = count +1
 		}
+	}
 
+
+	if( isInertial && (eccon == "ec" || eccon == "ecS") ) 
+	{
 		#be careful on ec inertial to send an startStored of 1220.5 because can use the 1220 that can be a positive displacement
 		#and then the 1221 can be negative and also the rest
 		#then is better to take the second number (do ceiling) to avoid a change of direction on the beginning of the movement
@@ -371,10 +375,8 @@ findCurvesNew <- function(displacement, eccon, isInertial, min_height, draw, tit
 		# On this example a ec can go from B to C. If it uses A,
 		#then there will be a change of direction that will make getSpeed to produce a mistaken spline
 
-		if(isInertial) {
-			for(i in 1:length(startStored)) {
-				startStored[i] = ceiling(startStored[i])
-			}
+		for(i in 1:length(startStored)) {
+			startStored[i] = ceiling(startStored[i])
 		}
 	}
 
@@ -617,7 +619,7 @@ findSmoothingsEC <- function(singleFile, displacement, curves, eccon, smoothingO
 				for(j in seq(as.numeric(smoothingOneC),0,by=-.01)) 
 				{
 					#write("calling speed 2", stderr())
-					speed <- getSpeed(eccentric.concentric, j)
+					speed <- getSpeed(concentric, j)
 					
 					smoothingOneEC = j
 					
@@ -811,52 +813,17 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 	}
 
+	print(c("smoothing at paint=",smoothing))
 	#speed
 	speed <- getSpeed(displacement, smoothing)
-
-	if(draw & showSpeed) {
-		ylimHeight = max(abs(range(speed$y)))
-		ylim=c(- 1.05 * ylimHeight, 1.05 * ylimHeight)	#put 0 in the middle, and have 5% margin at each side
-		if(knRanges[1] != "undefined")
-			ylim = knRanges$speedy
-		par(new=T)
 	
-		speedPlot=speed$y
-		#on rotatory inertial, concentric-eccentric, plot speed as ABS)
-		#if(inertialType == "ri" && eccon == "ce")
-		#	speedPlot=abs(speed$y)
-
-		if(highlight==FALSE)
-			plot(startX:length(speedPlot),speedPlot[startX:length(speedPlot)],type="l",
-			     xlim=c(1,length(displacement)),ylim=ylim,xlab="",ylab="",col=cols[1],lty=lty[1],lwd=1,axes=F)
-		else
-			plot(startX:length(speedPlot),speedPlot[startX:length(speedPlot)],type="l",
-			     xlim=c(1,length(displacement)),ylim=ylim,xlab="",ylab="",col="darkgreen",lty=2,lwd=3,axes=F)
-	}
-	
-	#time to arrive to max speed
-	maxSpeedT=min(which(speed$y == max(speed$y)))
-	if(draw & showSpeed & !superpose) {
-		abline(v=maxSpeedT, col=cols[1])
-		points(maxSpeedT, max(speed$y),col=cols[1])
-		mtext(text=paste(round(max(speed$y),2),"m/s",sep=""),side=3,
-		      at=maxSpeedT,cex=.8,col=cols[1], line=.5)
-		mtext(text=maxSpeedT,side=1,at=maxSpeedT,cex=.8,col=cols[1],line=-.2)
-
-		if(eccon != "c") {
-			minSpeedT=min(which(speed$y == min(speed$y)))
-			
-			abline(v=minSpeedT, col=cols[1])
-			points(minSpeedT, min(speed$y),col=cols[1])
-			mtext(text=paste(round(min(speed$y),2),"m/s",sep=""),side=3,
-			      at=minSpeedT,cex=.8,col=cols[1], line=.5)
-			mtext(text=minSpeedT,side=1,at=minSpeedT,cex=.8,col=cols[1],line=-.2)
-		}
-	}
-
-
 	#show extrema values in speed
 	speed.ext=extrema(speed$y)
+	
+	#accel (calculated here to use it on fixing inertialECstart and before plot speed
+	accel <- getAcceleration(speed)
+	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
+	accel$y <- accel$y * 1000
 
 
 	#if(draw & !superpose) 
@@ -933,24 +900,13 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		}
 	}
 	
+	#time to arrive to max speed
+	maxSpeedT=min(which(speed$y == max(speed$y)))
+
 	maxSpeedTInConcentric = maxSpeedT
 	if(eccon != "c")
 		maxSpeedTInConcentric = maxSpeedT - (length(eccentric) + length(isometric))
 		
-	#on rotatory inertial, concentric-eccentric, use speed as ABS)
-	#if(inertialType == "ri" && eccon == "ce")
-	#	speed$y=abs(speed$y)
-
-	accel <- getAcceleration(speed)
-	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
-	accel$y <- accel$y * 1000
-	
-	#print(accel$y)
-	#alternative R method (same result)
-	#accel2 <- D1ss( 1:length(speed$y), speed$y )
-	#accel2 <- accel2 * 1000
-	#print(accel2)
-
 	#define a propulsiveEnd value because it's used also in non-propulsive curves
 	propulsiveEnd = length(displacement)
 
@@ -965,16 +921,71 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 
 	print(c("propulsiveEnd at paint", propulsiveEnd))
 
+
+	# ---- start of inertialECstart ----
+
 	#on inertial ec. If the accel starts as negative, calcule avg values and peak values starting when the accel is positive
 	#because the acceleration done on the disc can only be positive
-	inertialECstart = 1
-	if(length(eccentric) > 0)
-		inertialECstart = min(eccentric)
+	#inertialECstart = 1
+	#if(length(eccentric) > 0)
+	#	inertialECstart = min(eccentric)
+	
+	#as acceleration can oscillate, start at the eccentric part where there are not negative values
+	#if(inertiaMomentum > 0 && eccon == "ec" && 
+	#   length(eccentric) > 0 && min(accel$y[eccentric]) < 0) #if there is eccentric data and there are negative vlaues
+	#{ 
+	#	inertialECstart = max(which(accel$y[eccentric] < 0)) +1
+	#	#abline(v=inertialECstart,lty=3,col="black") 
+	#}
+	#print(c("inertialECstart", inertialECstart))
+	#print(c("accel$y[eccentric]", accel$y[eccentric]))
+	#print(displacement[eccentric])
 
-	if(inertiaMomentum > 0 && eccon == "ec" && accel$y[1] < 0) {
-		inertialECstart <- min(which(accel$y > 0))
-		abline(v=inertialECstart,lty=3,col="black") 
+	#startX = inertialECstart #deactivated
+
+	# ---- end of inertialECstart ----
+	
+	
+	if(draw & showSpeed) {
+		ylimHeight = max(abs(range(speed$y)))
+		ylim=c(- 1.05 * ylimHeight, 1.05 * ylimHeight)	#put 0 in the middle, and have 5% margin at each side
+		if(knRanges[1] != "undefined")
+			ylim = knRanges$speedy
+		par(new=T)
+	
+		speedPlot=speed$y
+		#on rotatory inertial, concentric-eccentric, plot speed as ABS)
+		#if(inertialType == "ri" && eccon == "ce")
+		#	speedPlot=abs(speed$y)
+
+		if(highlight==FALSE)
+			plot(startX:length(speedPlot),speedPlot[startX:length(speedPlot)],type="l",
+			     xlim=c(1,length(displacement)),ylim=ylim,xlab="",ylab="",col=cols[1],lty=lty[1],lwd=1,axes=F)
+		else
+			plot(startX:length(speedPlot),speedPlot[startX:length(speedPlot)],type="l",
+			     xlim=c(1,length(displacement)),ylim=ylim,xlab="",ylab="",col="darkgreen",lty=2,lwd=3,axes=F)
+		
 	}
+	
+	if(draw & showSpeed & !superpose) {
+		abline(v=maxSpeedT, col=cols[1])
+		points(maxSpeedT, max(speed$y),col=cols[1])
+		mtext(text=paste(round(max(speed$y),2),"m/s",sep=""),side=3,
+		      at=maxSpeedT,cex=.8,col=cols[1], line=.5)
+		mtext(text=maxSpeedT,side=1,at=maxSpeedT,cex=.8,col=cols[1],line=-.2)
+
+		if(eccon != "c") {
+			minSpeedT=min(which(speed$y == min(speed$y)))
+			
+			abline(v=minSpeedT, col=cols[1])
+			points(minSpeedT, min(speed$y),col=cols[1])
+			mtext(text=paste(round(min(speed$y),2),"m/s",sep=""),side=3,
+			      at=minSpeedT,cex=.8,col=cols[1], line=.5)
+			mtext(text=minSpeedT,side=1,at=minSpeedT,cex=.8,col=cols[1],line=-.2)
+		}
+	}
+
+	
 
 
 	meanSpeedC = mean(speed$y[min(concentric):max(concentric)])
@@ -987,9 +998,9 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnd,y1=meanSpeedC,col=cols[1],code=3)
 		}
 	} else {
-		meanSpeedE = mean(speed$y[inertialECstart:max(eccentric)])
+		meanSpeedE = mean(speed$y[startX:max(eccentric)])
 		if(showSpeed) {
-			arrows(x0=inertialECstart,y0=meanSpeedE,x1=max(eccentric),y1=meanSpeedE,col=cols[1],code=3)
+			arrows(x0=startX,y0=meanSpeedE,x1=max(eccentric),y1=meanSpeedE,col=cols[1],code=3)
 			arrows(x0=min(concentric),y0=meanSpeedC,x1=propulsiveEnd,y1=meanSpeedC,col=cols[1],code=3)
 		}
 	}
@@ -1063,6 +1074,28 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	power = dynamics$power
 
 
+	if(draw && isInertial(encoderConfigurationName) && debug) 
+	{
+		#start blank graph with ylim of position
+		ylim = yrange
+		if(ylim[1] == "undefined") { 
+			ylim = NULL 
+			ylim = c(min(position-min(position)), max(position-min(position)))
+		}
+		par(new=T)
+		plot(0,0,type="n",axes=F,xlab="",ylab="", ylim=ylim)
+		
+		abline(h=100*dynamics$loopsAblines, col="yellow") #m -> cm
+		print("dynamics$loopsAblines")
+		print(dynamics$loopsAblines)
+		
+		print("ylim")
+		print(ylim)
+
+		#TODO: add here angleSpeed graph when diameter is variable (version 1.5.3)
+	}
+
+
 	if(draw & showForce) {
 		ylimHeight = max(abs(range(force)))
 		ylim=c(- 1.05 * ylimHeight, 1.05 * ylimHeight)	#put 0 in the middle, and have 5% margin at each side
@@ -1079,6 +1112,16 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 			axis(4, col=cols[2], lty=lty[2], line=axisLineRight, lwd=1, padj=-.5)
 			axisLineRight = axisLineRight +2
 		}
+		
+		if(isInertial(encoderConfigurationName) && debug) {
+			#print("dynamics$forceDisc")
+			#print(dynamics$forceDisc)
+			par(new=T)
+			plot(dynamics$forceDisc, col="blue", xlab="", ylab="", xlim=c(1,length(displacement)),ylim=ylim, type="p", pch=1, axes=F);
+
+			par(new=T)
+			plot(dynamics$forceBody, col="blue", xlab="", ylab="", xlim=c(1,length(displacement)),ylim=ylim, type="p", pch=3, axes=F);
+		}
 	}
 
 	#mark when it's air and land
@@ -1165,6 +1208,15 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		else
 			plot(startX:length(power),power[startX:length(power)],type="l",
 			     xlim=c(1,length(displacement)),ylim=ylim,xlab="",ylab="",col="darkred",lty=2,lwd=3,axes=F)
+	
+
+		if(isInertial(encoderConfigurationName) && debug) {
+			par(new=T)
+			plot(dynamics$powerDisc, col="orangered3", xlab="", ylab="", xlim=c(1,length(displacement)),ylim=ylim, type="p", pch=1, axes=F);
+
+			par(new=T)
+			plot(dynamics$powerBody, col="orangered3", xlab="", ylab="", xlim=c(1,length(displacement)),ylim=ylim, type="p", pch=3, axes=F);
+		}
 
 
 		meanPowerC = mean(power[min(concentric):max(concentric)])
@@ -1175,8 +1227,8 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 		if(eccon == "c") {
 			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnd,y1=meanPowerC,col=cols[3],code=3)
 		} else {
-			meanPowerE = mean(power[inertialECstart:max(eccentric)])
-			arrows(x0=inertialECstart,y0=meanPowerE,x1=max(eccentric),y1=meanPowerE,col=cols[3],code=3)
+			meanPowerE = mean(power[startX:max(eccentric)])
+			arrows(x0=startX,y0=meanPowerE,x1=max(eccentric),y1=meanPowerE,col=cols[3],code=3)
 			arrows(x0=min(concentric),y0=meanPowerC,x1=propulsiveEnd,y1=meanPowerC,col=cols[3],code=3)
 		}
 
@@ -1205,7 +1257,7 @@ paint <- function(displacement, eccon, xmin, xmax, yrange, knRanges, superpose,
 	}
 	
 	#time to arrive to peak power
-	powerTemp <- power[inertialECstart:length(power)]
+	powerTemp <- power[startX:length(power)]
 	peakPowerT <- min(which(power == max(powerTemp)))
 	if(draw & !superpose & showPower) {
 		abline(v=peakPowerT, col=cols[3])
@@ -2729,6 +2781,9 @@ doProcess <- function(options)
 			       else
 				       myEcconKn = "e"
 			}
+			print("start integer before kinematicsF __________")
+			print(c(curves[i,1], displacement[curves[i,1]]))
+
 			paf = rbind(paf,(pafGenerate(
 						     myEccon,
 						     kinematicsF(displacement[curves[i,1]:curves[i,2]], 
@@ -2748,13 +2803,6 @@ doProcess <- function(options)
 
 		rownames(paf)=rownames(curves)
 		
-		if(debug) {
-			#print("--------CURVES (propulsive is not calculated yet) --------------")
-			#print(curves)
-			#print("----------PAF---------------")
-			#print(paf)
-		}
-
 		if(op$Analysis == "powerBars") {
 			if(! singleFile) 
 				paintPowerPeakPowerBars(singleFile, op$Title, paf, 
@@ -2887,36 +2935,45 @@ doProcess <- function(options)
 		}
 		
 		if(op$Analysis == "curves" || writeCurves) {
+			#this columns are going to be removed from paf:
+
+			write("paf and pafCurves", stderr())
+			write(paf$meanSpeed, stderr())
+			pafCurves <- subset( paf, select = -c(mass, massBody, massExtra, inertiaMomentum) )
+			write(pafCurves$meanSpeed, stderr())
+
+
 			if(singleFile)
-				paf = cbind(
+				pafCurves = cbind(
 					  "1",			#seriesName
 					  "exerciseName",
 					  op$MassBody,
 					  op$MassExtra,
 					  curves[,1],
-					  curves[,2]-curves[,1],position[curves[,2]]-curves[,3],paf)
+					  curves[,2]-curves[,1],position[curves[,2]]-curves[,3],pafCurves)
 			else {
 				if(discardingCurves)
 					curvesHeight = curvesHeight[-discardedCurves]
 
-				paf = cbind(
+				pafCurves = cbind(
 					  curves[,9],		#seriesName
 					  curves[,4],		#exerciseName
 					  curves[,5],		#massBody
 					  curves[,6],		#massExtra
 					  curves[,1],		
-					  curves[,2]-curves[,1],curvesHeight,paf)
+					  curves[,2]-curves[,1],curvesHeight,pafCurves)
 			}
 
-			colnames(paf)=c("series","exercise","massBody","massExtra",
+			colnames(pafCurves) = c("series","exercise","massBody","massExtra",
 					"start","width","height",
 					"meanSpeed","maxSpeed","maxSpeedT",
 					"meanPower","peakPower","peakPowerT",
 					"pp_ppt",
 					"meanForce", "maxForce", "maxForceT",
-			  		"mass", "massBody", "massExtra", #unneded
-					"laterality","Inertia")
-			write.csv(paf, op$OutputData1, quote=FALSE)
+					"laterality"
+					)
+
+			write.csv(pafCurves, op$OutputData1, quote=FALSE)
 			#print("curves written")
 		}
 	}
