@@ -229,12 +229,27 @@ findTakeOff <- function(forceConcentric, maxSpeedTInConcentric)
 
 	return(takeoff)
 }
+	
 
+getSpeedSafe <- function(displacement, smoothing) {
+	#x vector should contain at least 4 different values
+	if(length(displacement) >= 4)
+		return(getSpeed(displacement, smoothing))
+	else
+		return(list(y=rep(0,length(displacement))))
+}
 getSpeed <- function(displacement, smoothing) {
 	#no change affected by encoderConfiguration
 	return (smooth.spline( 1:length(displacement), displacement, spar=smoothing))
 }
 
+getAccelerationSafe <- function(speed) {
+	#x vector should contain at least 4 different values
+	if(length(speed) >= 4)
+		return(getAcceleration(speed))
+	else
+		return(list(y=rep(0,length(speed))))
+}
 getAcceleration <- function(speed) {
 	#no change affected by encoderConfiguration
 	return (predict( speed, deriv=1 ))
@@ -346,7 +361,6 @@ reduceCurveBySpeed <- function(eccon, row, startT, startH, displacement, smoothi
 				x.end = i
 	}
 
-	#debug
 	#print(speed.ext$cross[,2])
 	#print(ext.cross.len)
 	#print(c("time1,time2",time1,time2))
@@ -369,6 +383,8 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 			encoderConfigurationName,diameter,diameterExt,anglePush,angleWeight,inertiaMomentum,gearedDown,
 			smoothingOneEC, smoothingOneC, g, eccon, isPropulsive)
 {
+	print("at kinematicsF")
+
 	smoothing = 0
 	if(eccon == "c" || eccon == "e")
 		smoothing = smoothingOneC
@@ -378,17 +394,10 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 
 	print(c("eccon, smoothing:",eccon, smoothing))
 
-	#x vector should contain at least 4 different values
-	if(length(displacement) >= 4)
-		speed <- getSpeed(displacement, smoothing)
-	else
-		speed=list(y=rep(0,length(displacement)))
+	speed <- getSpeedSafe(displacement, smoothing)
+	
+	accel <- getAccelerationSafe(speed)
 	
-	if(length(displacement) >= 4)
-		accel <- getAcceleration(speed)
-	else
-		accel=list(y=rep(0,length(displacement)))
-
 	#print(c(" ms",round(mean(speed$y),5)," ma",round(mean(accel$y),5)))
 	#print(c(" Ms",round(max(speed$y),5)," Ma",round(max(accel$y),5)))
 	#print(c(" |ms|",round(mean(abs(speed$y)),5)," |ma|:",round(mean(abs(accel$y)),5)))
@@ -396,8 +405,8 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 
 	#speed comes in mm/ms when derivate to accel its mm/ms^2 to convert it to m/s^2 need to *1000 because it's quadratic
 	accel$y <- accel$y * 1000 
-	errorSearching = FALSE
 
+	eccentric = 0
 	concentric = 0
 	propulsiveEnd = 0
 
@@ -453,10 +462,39 @@ kinematicsF <- function(displacement, massBody, massExtra, exercisePercentBodyWe
 	if( isPropulsive && ( eccon== "c" || eccon == "ec" ) )
 		end <- propulsiveEnd
 
-	if(inertiaMomentum > 0 && (eccon == "e" || eccon == "ec") && accel$y[1] < 0)
-		start <- min(which(accel$y > 0))
+	#as acceleration can oscillate, start at the eccentric part where there are not negative values
+	#print(c(inertiaMomentum, eccon, length(eccentric), min(accel$y[eccentric])))
+	if(inertiaMomentum > 0 && (eccon == "e" || eccon == "ec")) 
+	{
+		if(eccon=="e") {
+			eccentric=1:length(displacement)
+		}
+		
+		#if there is eccentric data and there are negative values
+	   	if(length(eccentric) > 0 && min(accel$y[eccentric]) < 0)
+		{ 
+			#print(c("length(eccentric)",length(eccentric)))
+			#print("min accel y eccentric ++++++++++++")
+			#print(c("min(accel$y[eccentric])",min(accel$y[eccentric])))
+	
+			#print(c("accel$y[eccentric]", accel$y[eccentric]))
+			#print("displacement eccentric")
+			#print(displacement[eccentric])
+
+
+
+			#deactivated:
+			#start = max(which(accel$y[eccentric] < 0)) +1
+			#print("------------ start -----------")
+			#print(start)
+		}
+	}
 
 	#print(c("kinematicsF start end",start,end))
+			
+	write("kinematicsF speed length and mean,", stderr())
+	write(length(speed$y[start:end]), stderr())
+	write(mean(speed$y[start:end]), stderr())
 
 	return(list(
 		    speedy = speed$y[start:end], 
@@ -491,12 +529,6 @@ findECPhases <- function(displacement,speed) {
 	crossMinRow=which(speed.ext$cross[,1] > searchMinSpeedEnd & speed.ext$cross[,1] < searchMaxSpeedIni)
 	#print(crossMinRow)
 			
-	#if (length(crossMinRow) > 0) {
-	#	print(crossMinRow)
-	#} else {
-	#	propulsiveEnd = length(displacement)
-	#	errorSearching = TRUE
-	#}
 	
 	eccentric = 0
 	isometric = 0
@@ -574,6 +606,7 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, iner
 	#print(kinematics$speedy)
 
 	meanSpeed <- mean(kinematics$speedy)
+
 	#max speed and max speed time can be at eccentric or concentric
 	maxSpeed <- max(abs(kinematics$speedy))
 	maxSpeedT <- min(which(abs(kinematics$speedy) == maxSpeed))
@@ -602,11 +635,13 @@ pafGenerate <- function(eccon, kinematics, massBody, massExtra, laterality, iner
 	#here paf is generated
 	#mass is not used by pafGenerate, but used by Kg/W (loadVSPower)
 	#meanForce and maxForce are not used by pafGenerate, but used by F/S (forceVSSpeed)
+	mass = kinematics$mass
+	#names will be used on graph.R writeCurves
 	return(data.frame(
 			  meanSpeed, maxSpeed, maxSpeedT,
 			  meanPower, peakPower, peakPowerT, pp_ppt,
 			  meanForce, maxForce, maxForceT,
-			  kinematics$mass, massBody, massExtra,		#kinematics$mass is Load
+			  mass, massBody, massExtra,		#kinematics$mass is Load
 			  laterality, inertiaMomentum)) 
 }
 
@@ -707,6 +742,12 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
 
 	position.m = abs(cumsum(displacement)) / 1000 #m
 	diameter.m = diameter / 100 #cm -> m
+    
+	angleSpeed = 0
+	forceDisc = 0
+	forceBody = 0
+	powerDisc = 0
+	powerBody = 0
   
   if(encoderConfigurationName == "ROTARYAXISINERTIAL" ||
        encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIAL" ||
@@ -715,27 +756,56 @@ getDynamicsInertial <- function(encoderConfigurationName, displacement, diameter
     angle = position.m * 2 / diameter.m
     angleSpeed = speed * 2 / diameter.m
     angleAccel = accel * 2 / diameter.m
-    force = abs(inertiaMomentum * angleAccel) * (2 / diameter.m) + mass * (accel + g)
-    power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * (accel + g) * speed
+    anglePush = 90 #TODO: send from C#
+
+    forceDisc = abs(inertiaMomentum * angleAccel) * (2 / diameter.m) 
+    forceBody = mass * (accel + g * sin(anglePush * pi / 180))
+    powerDisc = abs((inertiaMomentum * angleAccel) * angleSpeed)
+    powerBody = abs(mass * (accel + g * sin(anglePush * pi / 180)) * speed)
+
   } else if(encoderConfigurationName == "ROTARYAXISINERTIALMOVPULLEY" ||
               encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALMOVPULLEY" ||
               encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALMOVPULLEY"){
+    #With a moving pulley, the displacement of the body is half of the displacement of the rope in the inertial machine side
+    #So, the multiplier is 4 instead of 2 to get the rotational kinematics.
     angle = position.m * 4 / diameter.m
     angleSpeed = speed * 4 / diameter.m
     angleAccel = accel * 4 / diameter.m
-    force = abs(inertiaMomentum * angleAccel) * (2 / diameter.m) + mass * (accel + g)
-    power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * (accel + g) * speed
+    anglePush = 90 #TODO: send from C#
+    #The configuration covers horizontal, vertical and inclinated movements
+    #If the movement is vertical g*sin(alpha) = g
+    #If the movement is horizontal g*sin(alpha) = 0
+
+    forceDisc = abs(inertiaMomentum * angleAccel) * (2 / diameter.m)
+    forceBody = mass * (accel + g * sin(anglePush * pi / 180))
+    powerDisc = abs((inertiaMomentum * angleAccel) * angleSpeed)
+    powerBody = abs(mass * (accel + g * sin(anglePush * pi / 180)) * speed)
+
+
   } else if(encoderConfigurationName == "ROTARYAXISINERTIALLATERAL" ||
               encoderConfigurationName == "ROTARYFRICTIONAXISINERTIALLATERAL" ||
               encoderConfigurationName == "ROTARYFRICTIONSIDEINERTIALLATERAL"){
     angle = position.m * 2 / diameter.m
     angleSpeed = speed * 2 / diameter.m
     angleAccel = accel * 2 / diameter.m
-    force = abs(inertiaMomentum * angleAccel) * (2 / diameter.m) + mass * accel
-    power = abs((inertiaMomentum * angleAccel) * angleSpeed) + mass * accel * speed
+    anglePush = 0 #TODO: send from C#
+    
+    forceDisc = abs(inertiaMomentum * angleAccel) * (2 / diameter.m)
+    forceBody = mass * accel
+    powerDisc = abs((inertiaMomentum * angleAccel) * angleSpeed)
+    powerBody = abs(mass * accel * speed)
+
   }
 
-	return(list(displacement=displacement, mass=mass, force=force, power=power))
+  force = forceDisc + forceBody
+  power = powerDisc + powerBody
+
+  loopsMax = diameter.m * max(angle)
+  loopsAblines = seq(from=0, to=loopsMax, by=diameter.m*pi)
+
+	return(list(displacement=displacement, mass=mass, force=force, power=power, 
+		    loopsAblines=loopsAblines, angleSpeed=angleSpeed,
+		    forceDisc=forceDisc, forceBody=forceBody, powerDisc=powerDisc, powerBody=powerBody))
 }
 
 
