@@ -29,6 +29,8 @@ using System.Diagnostics; //Process
 
 using System.Collections; //ArrayList
 
+using System.Runtime.InteropServices;
+
 
 public class ChronoJump 
 {
@@ -41,7 +43,7 @@ public class ChronoJump
 
 	private string runningFileName; //useful for knowing if there are two chronojump instances
 	private string messageToShowOnBoot = "";
-	private string messageChrashedBefore = "";
+	private string messageCrashedBefore = "";
 	private bool chronojumpHasToExit = false;
 		
 	[Widget] Gtk.Button fakeSplashButton; //raised when splash win ended
@@ -54,6 +56,11 @@ public class ChronoJump
 	private static string baseDirectory;
 
 
+#if OSTYPE_WINDOWS
+	[DllImport("libglib-2.0-0.dll") /* willfully unmapped */ ]
+	static extern bool g_setenv (String env, String val, bool overwrite);
+#endif
+
 	public static void Main(string [] args) 
 	{/*
 		bool timeLogPassedOk = Log.Start(args);
@@ -65,7 +72,6 @@ public class ChronoJump
 		//1.4.10
 		Log.Start();
 		LogB.Debugging = true; //now LogB.Debug will be shown. Also there will be thread info on Warning, Error, Information
-	
 
 		var envPath = Environment.GetEnvironmentVariable ("PATH");
 		var rBinPath = "";
@@ -141,11 +147,41 @@ public class ChronoJump
 		}
 
 
-		Catalog.Init("chronojump",System.IO.Path.Combine(Util.GetPrefixDir(),"share/locale"));
-					
-			
-		new ChronoJump(args);
-		
+	string language = "";
+	if(File.Exists(System.IO.Path.Combine(Util.GetDatabaseDir(), "chronojump.db"))) {
+		try {
+			Sqlite.Connect();
+
+			/*
+			 * chronojump 1.5.2 converts DB 1.24 to 1.25 changing language to ""
+			 * but this operation is done later (on sqliteThings)
+			 * We need here! to define the language from the beginning
+			 * so we use language = "" if version is prior to 1.25
+			 */
+			string currentVersion = SqlitePreferences.Select("databaseVersion", false);
+			double currentVersionDouble = Convert.ToDouble(Util.ChangeDecimalSeparator(currentVersion));
+			if(currentVersionDouble < Convert.ToDouble(Util.ChangeDecimalSeparator("1.25")))
+				language = "";
+			else
+				language = SqlitePreferences.Select("language", false);
+
+			Sqlite.DisConnect();
+	
+			if(language != "") {
+				Environment.SetEnvironmentVariable ("LANGUAGE", language); //works
+#if OSTYPE_WINDOWS
+				g_setenv ("LANGUAGE", language, true);
+#endif
+			}
+		}
+		catch {
+			LogB.Warning("Problem reading language on start");
+		}
+	}
+
+	Catalog.Init("chronojump",System.IO.Path.Combine(Util.GetPrefixDir(),"share/locale"));
+
+	new ChronoJump(args);
 	}
 
 	bool createdSplashWin = false;
@@ -296,6 +332,7 @@ public class ChronoJump
 					LogB.Error(errorMessage);
 					messageToShowOnBoot += errorMessage;
 					chronojumpHasToExit = true;
+					return;
 				}
 				Sqlite.Connect();
 			}
@@ -417,7 +454,7 @@ public class ChronoJump
 				messageToShowOnBoot += "\n" + Catalog.GetString("Chronojump crashed before.") + "\n" +
 				       Catalog.GetString("Please, update to new version: ") + versionAvailableKnown + "\n";
 			else {
-				messageToShowOnBoot += messageChrashedBefore;
+				messageToShowOnBoot += messageCrashedBefore;
 				//SqlitePreferences.Update("videoOn", "False", true);
 			}
 		}
@@ -652,21 +689,21 @@ public class ChronoJump
 	/* ---------------------
 	 * other support methods 
 	 * ---------------------*/
-		
-	private void chronojumpCrashedBefore() {
-
+	
+	private void chronojumpCrashedBefore() 
+	{
 		/*
-		string windowsTextLog = "";
-			
-		string crashLogFile = Log.GetLast().Replace(".txt", "-crash.txt");
+		  string windowsTextLog = "";
+		  
+		  string crashLogFile = Log.GetLast().Replace(".txt", "-crash.txt");
 		//on vista there's no crash file because redirection is forbidden
 		if(UtilAll.IsWindows() && File.Exists(crashLogFile)) 
-			windowsTextLog = "\n" + crashLogFile;
-			*/
-
+		windowsTextLog = "\n" + crashLogFile;
+		*/
+			
 		//if there's a copy on temp...
-		if(File.Exists(Util.GetDatabaseTempDir() + Path.DirectorySeparatorChar + "chronojump.db")) {
-
+		if(File.Exists(Util.GetDatabaseTempDir() + Path.DirectorySeparatorChar + "chronojump.db")) 
+		{
 			// if exist also a file in default db location (improbable but done for solve eventual problems
 			if(File.Exists(Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "chronojump.db")) {
 				Util.BackupDatabase();//copy it to backup
@@ -675,26 +712,23 @@ public class ChronoJump
 
 			//move temp dir to default db location dir
 			File.Move(Util.GetDatabaseTempDir() + Path.DirectorySeparatorChar + "chronojump.db",
-				Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "chronojump.db");
+					Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "chronojump.db");
 		}
 
-
-		messageChrashedBefore = "\n" +
+		messageCrashedBefore = "\n" +
 			string.Format(Catalog.GetString("Chronojump {0} crashed before."), progVersion) + "\n\n" +
-			Catalog.GetString("Please, fill your email and click on 'Send error log' in order to fix this fast and contact you if appropiate.") + "\n\n" +
+			Catalog.GetString("Please, fill your email and click on 'Send error log' in order to fix this fast and contact you if appropriate.") + "\n\n" +
 			Catalog.GetString("Your help is needed.") + "\n";
 
-	
-		//messageChrashedBefore += "\n" + Catalog.GetString("Experimental webcam record has been disabled.") + "\n";
 
+		//messageCrashedBefore += "\n" + Catalog.GetString("Experimental webcam record has been disabled.") + "\n";
 
 		/*
 		 * This are the only outputs to Console. Other's use Log that prints to console and to log file
 		 * this doesn't go to log because it talks about log
 		 */
-		LogB.Warning(messageChrashedBefore);
-		
-		return;
+		LogB.Warning(messageCrashedBefore);
+			return;
 	}
 
 	//recuperate temp jumpRj or RunI if chronojump hangs
