@@ -288,21 +288,21 @@ public class Constants
 	public static string PotencyLaraMaleApplicantsSCFormulaShort = 
 		Catalog.GetString("Peak power") + " (Lara, 2006, m)";
 	public static string PotencyLaraMaleApplicantsSCFormula = PotencyLaraMaleApplicantsSCFormulaShort + 
-		" (" + Catalog.GetString("Male applicants to a Faculty of Sport Sciencies") + ") \n" +
+		" (" + Catalog.GetString("Male applicants to a Faculty of Sport Sciences") + ") \n" +
 		"(62.5*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (50.3*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2184.7";
 	
 	public static string PotencyLaraFemaleEliteVoleiFormulaShort = 
 		Catalog.GetString("Peak power") + " (Lara, 2006, fev)"; 
 	public static string PotencyLaraFemaleEliteVoleiFormula = PotencyLaraFemaleEliteVoleiFormulaShort + 
-		" (" + Catalog.GetString("Female elite volleybol") + ") \n" +
+		" (" + Catalog.GetString("Female elite volleyball") + ") \n" +
 		"(83.1*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (42*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2488";
 	
 	public static string PotencyLaraFemaleMediumVoleiFormulaShort = 
 		Catalog.GetString("Peak power") + " (Lara, 2006, fmv)";
 	public static string PotencyLaraFemaleMediumVoleiFormula = PotencyLaraFemaleMediumVoleiFormulaShort +
-		" (" + Catalog.GetString("Female medium volleybol") + ") \n" +
+		" (" + Catalog.GetString("Female medium volleyball") + ") \n" +
 		"(53.6*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (67.5*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -2624.1";
 	
@@ -310,7 +310,7 @@ public class Constants
 		Catalog.GetString("Peak power") + " (Lara, 2006, fsc)";
 	public static string PotencyLaraFemaleSCStudentsFormula = PotencyLaraFemaleSCStudentsFormulaShort +
 		" (" + Catalog.GetString("Peak power") + " (Lara, 2006, " + 
-		Catalog.GetString("Female sports sciencies students") + ") \n" +
+		Catalog.GetString("Female sports sciences students") + ") \n" +
 		"(56.7*" + Catalog.GetString("height") + "(cm))" +
 	        "+ (47.2*(" + Catalog.GetString("body weight") + "+" + Catalog.GetString("extra weight") + ")) -1772.6";
 	
@@ -398,6 +398,9 @@ public class Constants
 	public static string FileNamePulse = "pulse_menu.png";
 	public static string FileNameMultiChronopic = "multichronopic_menu.png";
 	
+	public static string FileNameJumpsFallCalculate = "dj-from-in.png";
+	public static string FileNameJumpsFallPredefined = "dj-from-out.png";
+	
 	public static string FileNameChronopic1 = "chronopic1.jpg";
 	public static string FileNameChronopic2 = "chronopic2.jpg";
 	public static string FileNameChronopic3 = "chronopic3.jpg";
@@ -437,6 +440,8 @@ public class Constants
 	public static string FileNameLog = "log_chronojump.txt";
 	public static string FileNameLogOld = "log_chronojump_old.txt";
 	
+	public static string FileNameConfig = "chronojump_config.txt";
+	
 	//30 colors defined
 	//see als UtilGtk that's not used by the server
 	public static string [] Colors = {
@@ -447,32 +452,7 @@ public class Constants
 		"LightGray", "LightGreen", "LightPink", "LightSalmon", "LightYellow", 
 		"MediumBlue", "MediumOrchid", "MediumPurple", "MediumTurquoise", "MediumVioletRed", "YellowGreen" 
 	};
-	
-	//for windows, on linux it takes language ok from the locale
-	public static string LanguageDefault = "en-GB:English (United Kingdom)";
-	public static string [] Languages = {
-		"ca-ES:Catalan", 
-		"zh-CN:Chinese", 
-		LanguageDefault, 
-		"dz-BT:Dzongkha",
-		"fi-FI:Finnish", 
-		"fr-FR:French", 
-		"oc-OC:Occitan",
-		"pt-BR:Portuguese (Brazil)", 
-		"pt-PT:Portuguese (Portugal)", 
-		"es-ES:Spanish (Spain)", 
-		"sv-SE:Swedish", 
-		"vi-VN:Vietnamese", 
-	};
 
-	/* *** ATTENTIOn ***: dz-BT deactivated on Windows compilation...
-	 * in the next release, do it better
-	 */
-
-	//TODO: add:
-	//ar (when there ara not fuzzy lines)
-	//see in both langs how to write as xx_XX
-	
 
 	public static string PortNamesWindows = 
 		string.Format(Catalog.GetString("Typical serial and USB-serial ports on Windows:") + 
@@ -567,8 +547,8 @@ public class Constants
 	public static string LevelUndefined = "Undefined"; 
 	private static string dumbVariableForTranslatingLevelUndefined = Catalog.GetString("Undefined");
 	public static int LevelSedentaryID = 0; 
-	public static string LevelSedentary = "Sedentary/Ocasional practice"; 
-	private static string dumbVariableForTranslatingLevelSedentary = Catalog.GetString("Sedentary/Ocasional practice");
+	public static string LevelSedentary = "Sedentary/Occasional practice"; 
+	private static string dumbVariableForTranslatingLevelSedentary = Catalog.GetString("Sedentary/Occasional practice");
 	public static string [] Levels = {
 		LevelUndefinedID.ToString() + ":" + Catalog.GetString(LevelUndefined), 
 		LevelSedentaryID.ToString() + ":" + Catalog.GetString(LevelSedentary), 
@@ -823,7 +803,7 @@ public class Constants
 	public enum EncoderAutoSaveCurve { ALL, NONE, BESTMEANPOWER }
 
 	public enum DoubleContact {
-		FIRST, AVERAGE, LAST
+		NONE, FIRST, AVERAGE, LAST
 	}
 	
 	//DISPLACED means: total
