@@ -270,7 +270,8 @@ public class EncoderCurve
 			string start, string duration, string height,
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
-			string PP_PPT)
+			string PP_PPT,
+			string meanForce, string maxForce, string maxForceT)
 	{
 		this.N = n;
 		this.Series = series;
@@ -288,6 +289,9 @@ public class EncoderCurve
 		this.PeakPower = peakPower;
 		this.PeakPowerT = peakPowerT;
 		this.PP_PPT = PP_PPT;	//PeakPower / PeakPowerTime
+		this.MeanForce = meanForce;
+		this.MaxForce = maxForce;
+		this.MaxForceT = maxForceT;
 	}
 
 	public string ToCSV(string decimalSeparator) {
@@ -301,7 +305,8 @@ public class EncoderCurve
 			Start + sep + Duration + sep + Height + sep + 
 			MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
 			MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
-			PP_PPT;
+			PP_PPT + sep +
+			MeanForce + sep + MaxForce + sep + MaxForceT;
 		
 		if(decimalSeparator == "COMMA")
 			str = Util.ConvertToComma(str);
@@ -896,7 +901,7 @@ public class EncoderBarsData {
 public class EncoderConfiguration {
 	public Constants.EncoderConfigurationNames name;
 	public Constants.EncoderType type;
-	public int position;
+	public int position; //used to find values on the EncoderConfigurationList. Numeration changes on every encoder and on not inertial/inertial
 	public string image;
 	public string code;	//this code will be stored untranslated but will be translated just to be shown
 	public string text;
@@ -905,6 +910,7 @@ public class EncoderConfiguration {
 	public bool has_angle_push;
 	public bool has_angle_weight;
 	public bool has_inertia;
+	public bool rotaryFrictionOnAxis;
 	public double d;	//axis
 	public double D;	//external disc or pulley
 	public int anglePush;
@@ -936,6 +942,7 @@ public class EncoderConfiguration {
 		has_angle_push = false;
 		has_angle_weight = false;
 		has_inertia = false;
+		rotaryFrictionOnAxis = false;
 		d = -1;
 		D = -1;
 		anglePush = -1;
@@ -958,9 +965,11 @@ public class EncoderConfiguration {
 		has_angle_push = false;
 		has_angle_weight = false;
 		has_inertia = false;
+		rotaryFrictionOnAxis = false;
 		gearedDown = 1;
 
 		// ---- LINEAR ----
+		// ---- not inertial
 		if(name == Constants.EncoderConfigurationNames.LINEAR) {
 			type = Constants.EncoderType.LINEAR;
 			position = 0;
@@ -975,22 +984,9 @@ public class EncoderConfiguration {
 			code = "Linear inv - barbell";
 			text = Catalog.GetString("Linear encoder inverted attached to a barbell.");
 		}
-		else if(name == Constants.EncoderConfigurationNames.LINEARINERTIAL) {
-			type = Constants.EncoderType.LINEAR;
-			position = 2;
-			image = Constants.FileNameEncoderLinearInertial;
-			code = "Linear - inertial machine";
-			text = Catalog.GetString("Linear encoder on inertia machine.") + "\n" + 
-				Catalog.GetString("Configuration NOT Recommended! Please use a rotary encoder.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
-				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
-			
-			has_d = true;
-			has_inertia = true;
-		}
 		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON1) {
 			type = Constants.EncoderType.LINEAR;
-			position = 3;
+			position = 2;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson1;
 			code = "Linear - barbell - moving pulley";
 			text = Catalog.GetString("Linear encoder attached to a barbell.") + " " + 
@@ -1001,7 +997,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON1INV) {
 			type = Constants.EncoderType.LINEAR;
-			position = 4;
+			position = 3;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson1Inv;
 			code = "Linear inv - barbell - moving pulley";
 			text = Catalog.GetString("Linear encoder inverted attached to a barbell.") + " " + 
@@ -1012,7 +1008,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON2) {
 			type = Constants.EncoderType.LINEAR;
-			position = 5;
+			position = 4;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson2;
 			code = "Linear - barbell - pulley - moving pulley";
 			text = Catalog.GetString("Linear encoder attached to a barbell.") + " " + 
@@ -1023,7 +1019,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYLINEARONPERSON2INV) {
 			type = Constants.EncoderType.LINEAR;
-			position = 6;
+			position = 5;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnPerson2Inv;
 			code = "Linear inv - barbell - pulley - moving pulley";
 			text = Catalog.GetString("Linear encoder inverted attached to a barbell.") + " " + 
@@ -1034,7 +1030,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.WEIGHTEDMOVPULLEYONLINEARENCODER) {
 			type = Constants.EncoderType.LINEAR;
-			position = 7;
+			position = 6;
 			image = Constants.FileNameEncoderWeightedMovPulleyOnLinearEncoder;
 			code = "Linear - moving pulley";
 			text = Catalog.GetString("Linear encoder attached to a weighted moving pulley.")
@@ -1044,7 +1040,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.LINEARONPLANE) {
 			type = Constants.EncoderType.LINEAR;
-			position = 8;
+			position = 7;
 			image = Constants.FileNameEncoderLinearOnPlane;
 			code = "Linear - inclinated plane";
 			text = Catalog.GetString("Linear encoder on a inclinated plane.");
@@ -1054,7 +1050,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.LINEARONPLANEWEIGHTDIFFANGLE) {
 			type = Constants.EncoderType.LINEAR;
-			position = 9;
+			position = 8;
 			image = Constants.FileNameEncoderLinearOnPlaneWeightDiffAngle;
 			code = "Linear - inclinated plane different angle";
 			text = Catalog.GetString("Linear encoder on a inclinated plane moving a weight in different angle.");
@@ -1062,7 +1058,22 @@ public class EncoderConfiguration {
 			has_angle_push = true;
 			has_angle_weight = true;
 		}
+		// ---- inertial
+		else if(name == Constants.EncoderConfigurationNames.LINEARINERTIAL) {
+			type = Constants.EncoderType.LINEAR;
+			position = 0;
+			image = Constants.FileNameEncoderLinearInertial;
+			code = "Linear - inertial machine";
+			text = Catalog.GetString("Linear encoder on inertia machine.") + "\n" + 
+				Catalog.GetString("Configuration NOT Recommended! Please use a rotary encoder.") + "\n" +
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
+			
+			has_d = true;
+			has_inertia = true;
+		}
 		// ---- ROTARY FRICTION ----
+		// ---- not inertial
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDE) {
 			type = Constants.EncoderType.ROTARYFRICTION;
 			position = 0;
@@ -1087,9 +1098,11 @@ public class EncoderConfiguration {
 			code = "Rotary friction - moving pulley";
 			text = Catalog.GetString("Rotary friction encoder on weighted moving pulley.");
 		}
+		// ---- inertial
+		// ---- rotary friction not on axis
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIAL) {
 			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 3;
+			position = 0;
 			image = Constants.FileNameEncoderFrictionSideInertial;
 			code = "Rotary friction - inertial machine side";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine side.") + "\n" +
@@ -1100,24 +1113,12 @@ public class EncoderConfiguration {
 			has_D = true;
 			has_inertia = true;
 		}
-		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIAL) {
-			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 4;
-			image = Constants.FileNameEncoderFrictionAxisInertial;
-			code = "Rotary friction axis - inertial machine axis";
-			text = Catalog.GetString("Rotary friction encoder on inertial machine axis.") + "\n" +
-				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
-				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
-
-			has_d = true;
-			has_inertia = true;
-		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIALLATERAL) {
 			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 5;
+			position = 1;
 			image = Constants.FileNameEncoderFrictionSideInertialLateral;
-			code = "Rotary friction - inertial machine side - lateral movement";
-			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving laterally.") + "\n" +
+			code = "Rotary friction - inertial machine side - horizontal movement";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving horizontally.") + "\n" +
 				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
@@ -1125,21 +1126,9 @@ public class EncoderConfiguration {
 			has_D = true;
 			has_inertia = true;
 		}
-		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIALLATERAL) {
-			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 6;
-			image = Constants.FileNameEncoderFrictionAxisInertialLateral;
-			code = "Rotary friction - inertial machine axis - lateral movement";
-			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving laterally.") + "\n" +
-				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
-				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
-
-			has_d = true;
-			has_inertia = true;
-		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONSIDEINERTIALMOVPULLEY) {
 			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 7;
+			position = 2;
 			image = Constants.FileNameEncoderFrictionSideInertialMovPulley;
 			code = "Rotary friction - inertial machine side geared up";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine geared up.") + "\n" +
@@ -1153,9 +1142,37 @@ public class EncoderConfiguration {
 			
 			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
 		}
+
+		// ---- rotary friction on axis
+		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIAL) {
+			type = Constants.EncoderType.ROTARYFRICTION;
+			position = 0;
+			image = Constants.FileNameEncoderFrictionAxisInertial;
+			code = "Rotary friction axis - inertial machine axis";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine axis.") + "\n" +
+				"*" + Catalog.GetString("Person has to start fully extended (on the toes).") + "*" + "\n" + 
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
+
+			has_d = true;
+			has_inertia = true;
+			rotaryFrictionOnAxis = true;
+		}
+		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIALLATERAL) {
+			type = Constants.EncoderType.ROTARYFRICTION;
+			position = 1;
+			image = Constants.FileNameEncoderFrictionAxisInertialLateral;
+			code = "Rotary friction - inertial machine axis - horizontal movement";
+			text = Catalog.GetString("Rotary friction encoder on inertial machine when person is moving horizontally.") + "\n" +
+				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
+				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
+
+			has_d = true;
+			has_inertia = true;
+			rotaryFrictionOnAxis = true;
+		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYFRICTIONAXISINERTIALMOVPULLEY) {
 			type = Constants.EncoderType.ROTARYFRICTION;
-			position = 8;
+			position = 2;
 			image = Constants.FileNameEncoderFrictionAxisInertialMovPulley;
 			code = "Rotary friction - inertial machine axis geared up";
 			text = Catalog.GetString("Rotary friction encoder on inertial machine geared up.") + "\n" +
@@ -1165,10 +1182,13 @@ public class EncoderConfiguration {
 
 			has_d = true;
 			has_inertia = true;
+			rotaryFrictionOnAxis = true;
 			
 			gearedDown = -2; //gearedDown is not used in inertial machines. It's hardcoded
 		}
+
 		// ---- ROTARY AXIS ----
+		// ---- not inertial
 		else if(name == Constants.EncoderConfigurationNames.ROTARYAXIS) {
 			type = Constants.EncoderType.ROTARYAXIS;
 			position = 0;
@@ -1188,9 +1208,10 @@ public class EncoderConfiguration {
 			
 			gearedDown = 2;
 		}
+		// ---- inertial
 		else if(name == Constants.EncoderConfigurationNames.ROTARYAXISINERTIAL) {
 			type = Constants.EncoderType.ROTARYAXIS;
-			position = 2;
+			position = 0;
 			image = Constants.FileNameEncoderAxisInertial;
 			code = "Rotary axis - inertial machine";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine.") + "\n" +
@@ -1202,10 +1223,10 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYAXISINERTIALLATERAL) {
 			type = Constants.EncoderType.ROTARYAXIS;
-			position = 3;
+			position = 1;
 			image = Constants.FileNameEncoderAxisInertialLateral;
-			code = "Rotary axis - inertial machine - lateral movement";
-			text = Catalog.GetString("Rotary axis encoder on inertial machine when person is moving laterally.") + "\n" +
+			code = "Rotary axis - inertial machine - horizontal movement";
+			text = Catalog.GetString("Rotary axis encoder on inertial machine when person is moving horizontally.") + "\n" +
 				"*" + Catalog.GetString("Start capture with the string completely unwrapped.") + "*" + "\n" +
 				Catalog.GetString("On inertial machines, 'd' means the average diameter where the pull-push string is rolled");
 
@@ -1214,7 +1235,7 @@ public class EncoderConfiguration {
 		}
 		else if(name == Constants.EncoderConfigurationNames.ROTARYAXISINERTIALMOVPULLEY) {
 			type = Constants.EncoderType.ROTARYAXIS;
-			position = 4;
+			position = 2;
 			image = Constants.FileNameEncoderAxisInertialMovPulley;
 			code = "Rotary axis - inertial machine geared up";
 			text = Catalog.GetString("Rotary axis encoder on inertial machine geared up.") + "\n" +
