@@ -26,7 +26,8 @@ using Glade;
 using Mono.Unix;
 
 
-public class EncoderConfigurationWindow {
+public class EncoderConfigurationWindow 
+{
 	[Widget] Gtk.Window encoder_configuration;
 	[Widget] Gtk.Image image_encoder_linear;
 	[Widget] Gtk.Image image_encoder_rotary_friction;
@@ -36,7 +37,18 @@ public class EncoderConfigurationWindow {
 	[Widget] Gtk.RadioButton radio_linear;
 	[Widget] Gtk.RadioButton radio_rotary_friction;
 	[Widget] Gtk.RadioButton radio_rotary_axis;
+	
+	[Widget] Gtk.RadioButton radio_gravity;
+	[Widget] Gtk.RadioButton radio_inertia;
+		
+	[Widget] Gtk.CheckButton check_rotary_friction_inertia_on_axis;
+	[Widget] Gtk.HBox hbox_encoder_types;
+	[Widget] Gtk.Alignment alignment_options;
+	
+	[Widget] Gtk.Button button_previous;
+	[Widget] Gtk.Button button_next;
 	[Widget] Gtk.Label label_count;
+
 	[Widget] Gtk.TextView textview;
 	[Widget] Gtk.Box hbox_d;
 	[Widget] Gtk.Box hbox_D;
@@ -77,12 +89,15 @@ public class EncoderConfigurationWindow {
 	ArrayList list;
 	int listCurrent = 0; //current item on list
 	Pixbuf pixbuf;
+	bool definedInConfig;
 
-	EncoderConfigurationWindow () {
+	EncoderConfigurationWindow (bool definedInConfig) {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "encoder_configuration", "chronojump");
 		gladeXML.Autoconnect(this);
 		
+		this.definedInConfig = definedInConfig;
+		
 		//three encoder types	
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameEncoderTypeLinear);
 		image_encoder_linear.Pixbuf = pixbuf;
@@ -100,11 +115,11 @@ public class EncoderConfigurationWindow {
 		UtilGtk.IconWindow(encoder_configuration);
 	}
 	
-	static public EncoderConfigurationWindow View (EncoderConfiguration ec) {
+	static public EncoderConfigurationWindow View (EncoderConfiguration ec, bool definedInConfig) {
 		if (EncoderConfigurationWindowBox == null) {
-			EncoderConfigurationWindowBox = new EncoderConfigurationWindow ();
+			EncoderConfigurationWindowBox = new EncoderConfigurationWindow (definedInConfig);
 		}
-		
+
 		//activate default radiobutton
 		if(ec.type == Constants.EncoderType.ROTARYFRICTION)
 			EncoderConfigurationWindowBox.radio_rotary_friction.Active = true;
@@ -113,12 +128,28 @@ public class EncoderConfigurationWindow {
 		else	//linear
 			EncoderConfigurationWindowBox.radio_linear.Active = true;
 
+		if(! ec.has_inertia)
+			EncoderConfigurationWindowBox.radio_gravity.Active = true;
+		else
+			EncoderConfigurationWindowBox.radio_inertia.Active = true;
+		
+		EncoderConfigurationWindowBox.check_rotary_friction_inertia_on_axis.Active = ec.rotaryFrictionOnAxis;
 
-		EncoderConfigurationWindowBox.initializeList(ec.type, ec.position);
+
+		EncoderConfigurationWindowBox.initializeList(ec.type, ec.has_inertia, ec.rotaryFrictionOnAxis, ec.position);
 		
 		EncoderConfigurationWindowBox.putValuesStoredPreviously(
 				ec.d, ec.D, ec.anglePush, ec.angleWeight, 
 				ec.inertiaMachine, ec.extraWeightGrams, ec.extraWeightLength);
+		
+
+		//id definedInConfig then only few things can change
+		if(definedInConfig) {
+			EncoderConfigurationWindowBox.hbox_encoder_types.Visible = false;
+			EncoderConfigurationWindowBox.check_rotary_friction_inertia_on_axis.Visible = false;
+			EncoderConfigurationWindowBox.alignment_options.Visible = false;
+			EncoderConfigurationWindowBox.vbox_inertia_calcule.Visible = false;
+		}
 	
 		EncoderConfigurationWindowBox.encoder_configuration.Show ();
 		return EncoderConfigurationWindowBox;
@@ -126,40 +157,87 @@ public class EncoderConfigurationWindow {
 	
 	private void on_radio_encoder_type_linear_toggled (object obj, EventArgs args) {
 		if(radio_linear.Active)
-			initializeList(Constants.EncoderType.LINEAR, 0);
+			initializeList(Constants.EncoderType.LINEAR, 
+					radio_inertia.Active, false, 0);
 	}
 	private void on_radio_encoder_type_rotary_friction_toggled (object obj, EventArgs args) {
 		if(radio_rotary_friction.Active)
-			initializeList(Constants.EncoderType.ROTARYFRICTION, 0);
+			initializeList(Constants.EncoderType.ROTARYFRICTION, 
+					radio_inertia.Active, 
+					(radio_inertia.Active && check_rotary_friction_inertia_on_axis.Active), 
+					0);
 	}
 	private void on_radio_encoder_type_rotary_axis_toggled (object obj, EventArgs args) {
 		if(radio_rotary_axis.Active)
-			initializeList(Constants.EncoderType.ROTARYAXIS, 0);
+			initializeList(Constants.EncoderType.ROTARYAXIS, 
+					radio_inertia.Active, false, 0);
 	}
 	
-	private void initializeList(Constants.EncoderType type, int position) {
-		list = UtilEncoder.EncoderConfigurationList(type);
+	private void on_radio_gravity_toggled (object obj, EventArgs args) {
+		if(radio_gravity.Active) {
+			if(radio_linear.Active)
+				initializeList(Constants.EncoderType.LINEAR, false, false, 0);
+			else if(radio_rotary_friction.Active)
+				initializeList(Constants.EncoderType.ROTARYFRICTION, false, false, 0);
+			else //(radio_rotary_axis.Active)
+				initializeList(Constants.EncoderType.ROTARYAXIS, false, false, 0);
+		}
+	}
+	private void on_radio_inertia_toggled (object obj, EventArgs args) {
+		if(radio_inertia.Active) {
+			if(radio_linear.Active)
+				initializeList(Constants.EncoderType.LINEAR, true, false, 0);
+			else if(radio_rotary_friction.Active)
+				initializeList(Constants.EncoderType.ROTARYFRICTION, true, check_rotary_friction_inertia_on_axis.Active,  0);
+			else //(radio_rotary_axis.Active)
+				initializeList(Constants.EncoderType.ROTARYAXIS, true, false, 0);
+		}
+	}
+
+	private void check_rotary_friction_inertia_on_axis_is_visible() {
+		check_rotary_friction_inertia_on_axis.Visible = (radio_rotary_friction.Active && ! radio_gravity.Active);
+	}
+	
+	private void on_check_rotary_friction_inertia_on_axis_toggled (object obj, EventArgs args) {
+		on_radio_inertia_toggled(obj, args);
+	}
+	
+
+	private void initializeList(Constants.EncoderType type, bool inertial, bool rotaryFrictionOnAxis, int position) 
+	{
+		check_rotary_friction_inertia_on_axis_is_visible();
+
+		list = UtilEncoder.EncoderConfigurationList(type, inertial, rotaryFrictionOnAxis);
+
 		listCurrent = position; //current item on list
 		
+		buttons_previous_next_sensitive();
 		selectedModeChanged();
 	}
 	
 	private void on_button_previous_clicked (object o, EventArgs args) {
 		listCurrent --;
 		if(listCurrent < 0)
-			listCurrent = list.Count -1;
+			listCurrent = 0;
 		
+		buttons_previous_next_sensitive();
 		selectedModeChanged();
 	}
 
 	private void on_button_next_clicked (object o, EventArgs args) {
 		listCurrent ++;
 		if(listCurrent > list.Count -1)
-			listCurrent = 0;
-
+			listCurrent = list.Count -1;
+		
+		buttons_previous_next_sensitive();
 		selectedModeChanged();
 	}
 
+	private void buttons_previous_next_sensitive() {
+		button_previous.Sensitive = (listCurrent > 0);
+		button_next.Sensitive = (listCurrent < list.Count -1);
+	}
+
 	private void selectedModeChanged() {
 		EncoderConfiguration ec = (EncoderConfiguration) list[listCurrent];
 		
@@ -177,7 +255,7 @@ public class EncoderConfigurationWindow {
 		hbox_inertia.Visible = ec.has_inertia;
 		hbox_inertia_mass.Visible = ec.has_inertia;
 		hbox_inertia_length.Visible = ec.has_inertia;
-		vbox_inertia_calcule.Visible = ec.has_inertia;
+		vbox_inertia_calcule.Visible = (ec.has_inertia && ! definedInConfig);
 		
 		label_count.Text = (listCurrent + 1).ToString() + " / " + list.Count.ToString();
 	
