@@ -38,39 +38,86 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Entry entry_raspberry_extra_weight;
 	[Widget] Gtk.Box hbox_encoder_capture_extra_mass_no_raspberry;
 	[Widget] Gtk.Box hbox_encoder_capture_extra_mass_raspberry;
+	
+	//config.EncoderNameAndCapture
+	[Widget] Gtk.Box hbox_encoder_person;
+	[Widget] Gtk.Label label_encoder_person_name;
+	[Widget] Gtk.Button button_encoder_person_change;
+	
+	//shown when menu is hidden
+	[Widget] Gtk.Button button_preferences_not_menu;
 
 
+	private bool useVideo = true;
+	private Config.AutodetectPortEnum configAutodetectPort = Config.AutodetectPortEnum.ACTIVE;
+
 	private enum linuxTypeEnum { NOTLINUX, LINUX, RASPBERRY, NETWORKS }
 	private linuxTypeEnum linuxType;
-	
-	//networks is a raspberry connected to the server	
-	private static linuxTypeEnum getLinuxTypes() 
-	{
-		if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX) 
-		{
-			if(Util.FileExists(Util.GetChronojumpNetworksFile()))
-				return(linuxTypeEnum.NETWORKS);
-			else if(Util.FileExists(Util.GetChronojumpRaspberryFile()))
-				return(linuxTypeEnum.RASPBERRY);
-			else
-				return(linuxTypeEnum.LINUX);
-		}
-		return(linuxTypeEnum.NOTLINUX);
-	}
+	private bool encoderConfigurationDefinedFromFile = false;
 
-	
-	private void raspberryOrNetworksInit() {
-		linuxType = getLinuxTypes();
-	
-		if(linuxType == linuxTypeEnum.RASPBERRY || linuxType == linuxTypeEnum.NETWORKS) 
-		{
+
+	private void configInit() 
+	{
+		//trying new Config class
+		Config config = new Config();
+		config.Read();
+		LogB.Information("Config:\n" + config.ToString());
+
+		if(config.Maximized)
+			app1.Maximize();
+		if(config.CustomButtons) {
 			hbox_encoder_capture_extra_mass_no_raspberry.Visible = false;
 			hbox_encoder_capture_extra_mass_raspberry.Visible = true;
-
+		}
+		if(! config.UseVideo) {
+			useVideo = false;
 			alignment_video_encoder.Visible = false;
-			//TODO: put the no connect video here.
+		}
+		
+		configAutodetectPort = config.AutodetectPort;
+		
+		//show only power
+		if(config.OnlyEncoder)
+			select_menuitem_mode_toggled(menuitem_modes.POWER);
+		
+		if(config.PersonWinHide) {
+			//vbox_persons.Visible = false;
+			notebook_session_person.Visible = false;
+			hbox_encoder_person.Visible = true;
+		}
+		
+		if(config.EncoderAnalyzeHide) {
+			hbox_encoder_sup_capture_analyze_two_buttons.Visible = false;
+		}
+		
+		if(config.Econf != null) {
+			encoderConfigurationDefinedFromFile = true;
+			encoderConfigurationCurrent = config.Econf;
+			encoderConfigurationGUIUpdate();
+			//TODO: allow to see full data, but don't allow to change it (Open window content as unsensitive)
+		}
+		
+		if(config.SessionMode == Config.SessionModeEnum.UNIQUE)	
+		{
+			main_menu.Visible = false;
+			button_preferences_not_menu.Visible = true;
+
+			if(! Sqlite.Exists(false, Constants.SessionTable, "session")) {
+				//this creates the session and inserts at DB
+				currentSession = new Session(
+						"session", "", DateTime.Today,	//name, place, dateTime
+						Constants.SportUndefinedID, Constants.SpeciallityUndefinedID, Constants.LevelUndefinedID,
+						"", Constants.ServerUndefinedID); //comments, serverID
+			} else
+				currentSession = SqliteSession.SelectByName("session");
+			
+			on_load_session_accepted();
 		}
 
+		//TODO
+		//RunScriptOnExit
+
+		/*
 		if(linuxType == linuxTypeEnum.NETWORKS) {
 			//mostrar directament el power
 			select_menuitem_mode_toggled(menuitem_modes.POWER);
@@ -79,7 +126,7 @@ public partial class ChronoJumpWindow
 			main_menu.Visible = false;
 			
 			//no mostrar persones
-			vbox_persons.Visible = false;
+			//vbox_persons.Visible = false;
 			//TODO: rfid can be here, also machine, maybe weight, other features
 			//time, gym, ...
 
@@ -91,12 +138,7 @@ public partial class ChronoJumpWindow
 			hbox_encoder_sup_capture_analyze.Sensitive = true;
 			notebook_encoder_sup.Sensitive = false;
 		}
-
-		//si es rapsberry o si es networks cal desactivar camera
-		
-		//maximize now, at the end of tweaks
-		if(linuxType == linuxTypeEnum.RASPBERRY || linuxType == linuxTypeEnum.NETWORKS)
-			app1.Maximize();
+		*/
 	}
 
 	//rfid
@@ -112,3 +154,4 @@ public partial class ChronoJumpWindow
 	}
 
 }
+
