@@ -878,8 +878,8 @@ public class PersonAddModifyWindow
 	//
 	//if we are adding a person, currentPerson.UniqueID it's -1
 	//if we are modifying a person, currentPerson.UniqueID is obviously it's ID
-	//hidePhotoStuff is true on raspberry to not use camera
-	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool hidePhotoStuff) {
+	//showPhotoStuff is false on raspberry to not use camera
+	PersonAddModifyWindow (Gtk.Window parent, Session currentSession, Person currentPerson, bool showPhotoStuff) {
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "chronojump.glade", "person_win", null);
 		gladeXML.Autoconnect(this);
@@ -911,9 +911,7 @@ public class PersonAddModifyWindow
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameZoomInIcon);
 		image_zoom.Pixbuf = pixbuf;
 
-		if(hidePhotoStuff)
-			vbox_photo.Visible = false;
-		else {
+		if(showPhotoStuff) {
 			string photoFile = Util.GetPhotoFileName(true, currentPerson.UniqueID);
 			if(File.Exists(photoFile)) {
 				try {
@@ -934,6 +932,8 @@ public class PersonAddModifyWindow
 			else
 				button_zoom.Sensitive = false;
 		}
+		else
+			vbox_photo.Visible = false;
 			
 		fakeButtonAccept = new Gtk.Button();
 
@@ -953,7 +953,7 @@ public class PersonAddModifyWindow
 			File.Copy(fileName, tempFileName, true);
 		}
 
-		new DialogImageTest(currentPerson.Name, tempFileName);
+		new DialogImageTest(currentPerson.Name, tempFileName, DialogImageTest.ArchiveType.FILE);
 	}
 
 	Gtk.Window capturerWindow;
@@ -1097,10 +1097,10 @@ public class PersonAddModifyWindow
 	
 	static public PersonAddModifyWindow Show (Gtk.Window parent, 
 			Session mySession, Person currentPerson, int pDN, 
-			Gtk.CheckButton app1_checkbutton_video, bool hidePhotoStuff)
+			Gtk.CheckButton app1_checkbutton_video, bool showPhotoStuff)
 	{
 		if (PersonAddModifyWindowBox == null) {
-			PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson, hidePhotoStuff);
+			PersonAddModifyWindowBox = new PersonAddModifyWindow (parent, mySession, currentPerson, showPhotoStuff);
 		}
 
 		PersonAddModifyWindowBox.pDN = pDN;
@@ -1432,7 +1432,7 @@ public class PersonAddModifyWindow
 				
 		//if it's sedentary, put sport to none
 		/*
-		 * Now undone because sedentary has renamed to "sedentary/Ocasional practice"
+		 * Now undone because sedentary has renamed to "sedentary/Occasional practice"
 		if(UtilGtk.ComboGetActive(combo_levels) == "0:" + Catalog.GetString(Constants.LevelSedentary))
 			combo_sports.Active = UtilGtk.ComboMakeActive(sports, "2:" + Catalog.GetString(Constants.SportNone));
 		*/
@@ -1550,7 +1550,7 @@ public class PersonAddModifyWindow
 			if(!adding && (double) spinbutton_weight.Value != weightIni) {
 				//see if this person has done jumps with weight
 				string [] myJumpsNormal = SqliteJump.SelectJumps(false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
-				string [] myJumpsReactive = SqliteJumpRj.SelectJumps(currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
+				string [] myJumpsReactive = SqliteJumpRj.SelectJumps(false, currentSession.UniqueID, currentPerson.UniqueID, "withWeight", "");
 
 				if(myJumpsNormal.Length > 0 || myJumpsReactive.Length > 0) {
 					//create the convertWeight Window
@@ -1889,8 +1889,21 @@ public class PersonAddMultipleWindow {
 		fc.Filter.AddPattern("*.CSV");
 
 		ArrayList array = new ArrayList();
-		if (fc.Run() == (int)ResponseType.Accept) { 
-			System.IO.FileStream file=System.IO.File.OpenRead(fc.Filename); 
+		if (fc.Run() == (int)ResponseType.Accept) 
+		{
+			LogB.Warning("Opening CSV...");
+			System.IO.FileStream file;
+			try {
+				file = System.IO.File.OpenRead(fc.Filename); 
+			} catch {
+				LogB.Warning("Catched, maybe is used by another program");
+				new DialogMessage(Constants.MessageTypes.WARNING, 
+						Catalog.GetString("Sorry, video cannot be stored.") + "\n\n" +
+						Catalog.GetString("Maybe this file is opened by an SpreadSheet software like Excel. Please, close that program.")
+						);
+				fc.Destroy();
+				return;
+			}
 
 			List<string> columns = new List<string>();
 			using (var reader = new CsvFileReader(fc.Filename))
@@ -1973,7 +1986,7 @@ public class PersonAddMultipleWindow {
 		label_csv_help.Text =
 			"<b>" + Catalog.GetString("Import persons from an spreadsheet. Eg. Excel, LibreOffice, Google Drive.") + "</b>\n\n" +
 			Catalog.GetString("Open the spreadsheet with the persons data to be added.") + "\n" +
-			Catalog.GetString("Spreadsheed structure need to have this structure:");
+			Catalog.GetString("Spreadsheet structure need to have this structure:");
 		label_csv_help.UseMarkup = true;
 
 		notebook.CurrentPage = 1;
@@ -2069,7 +2082,7 @@ public class PersonAddMultipleWindow {
 		if(currentSession.PersonsSportID != Constants.SportUndefinedID)
 			sportStuffString += Catalog.GetString("Sport") + ":<i>" + Catalog.GetString(SqliteSport.Select(false, currentSession.PersonsSportID).Name) + "</i>.";
 		if(currentSession.PersonsSpeciallityID != Constants.SpeciallityUndefinedID)
-			sportStuffString += " " + Catalog.GetString("Speciallity") + ":<i>" + SqliteSpeciallity.Select(false, currentSession.PersonsSpeciallityID) + "</i>.";
+			sportStuffString += " " + Catalog.GetString("Specialty") + ":<i>" + SqliteSpeciallity.Select(false, currentSession.PersonsSpeciallityID) + "</i>.";
 		if(currentSession.PersonsPractice != Constants.LevelUndefinedID)
 			sportStuffString += " " + Catalog.GetString("Level") + ":<i>" + Util.FindLevelName(currentSession.PersonsPractice) + "</i>.";
 
@@ -2415,5 +2428,3 @@ public class PersonShowAllEventsWindow {
 		PersonShowAllEventsWindowBox = null;
 	}
 }
-
-
