@@ -29,14 +29,15 @@ using System.Text; //StringBuilder
 using System.Collections; //ArrayList
 using Mono.Unix;
 using System.Threading;
+using System.Globalization; //CultureInfo stuff
+
 
 public class PreferencesWindow {
 	
 	[Widget] Gtk.Window preferences_win;
 
-	[Widget] Gtk.Label label_database;
-	[Widget] Gtk.Label label_database_temp;
-	
+
+	//database tab
 	[Widget] Gtk.Button button_db_folder_open;
 
 	//this three are unneded because cannot be unchecked
@@ -50,67 +51,86 @@ public class PreferencesWindow {
 	[Widget] Gtk.Box hbox_backup_doing;
 	[Widget] Gtk.ProgressBar pulsebar;
 
-	[Widget] Gtk.ComboBox combo_decimals;
+	
+	//jumps tab	
 	[Widget] Gtk.CheckButton checkbutton_power;
 	[Widget] Gtk.CheckButton checkbutton_stiffness;
 	[Widget] Gtk.CheckButton checkbutton_initial_speed;
 	[Widget] Gtk.CheckButton checkbutton_angle;
-	
 	[Widget] Gtk.CheckButton checkbutton_show_tv_tc_index;
 	[Widget] Gtk.Box hbox_indexes;
 	[Widget] Gtk.RadioButton radiobutton_show_q_index;
 	[Widget] Gtk.RadioButton radiobutton_show_dj_index;
-	
-	[Widget] Gtk.CheckButton checkbutton_ask_deletion;
-
 	[Widget] Gtk.RadioButton radio_elevation_height;
 	[Widget] Gtk.RadioButton radio_elevation_tf;
-	[Widget] Gtk.RadioButton radio_speed_ms;
-	[Widget] Gtk.RadioButton radio_speed_km;
 	[Widget] Gtk.RadioButton radio_weight_percent;
 	[Widget] Gtk.RadioButton radio_weight_kg;
+	[Widget] Gtk.RadioButton radio_use_heights_on_jump_indexes;
+	[Widget] Gtk.RadioButton radio_do_not_use_heights_on_jump_indexes;
+			
+	//runs tab	
+	[Widget] Gtk.RadioButton radio_speed_ms;
+	[Widget] Gtk.RadioButton radio_speed_km;
+	[Widget] Gtk.RadioButton radio_runs_speed_start_arrival; 
+	[Widget] Gtk.RadioButton radio_runs_speed_start_leaving; 
+	[Widget] Gtk.Box vbox_runs_prevent_double_contact;
+	[Widget] Gtk.CheckButton checkbutton_runs_prevent_double_contact;
+	[Widget] Gtk.SpinButton spinbutton_runs_prevent_double_contact;
+	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_first;
+	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_average;
+	[Widget] Gtk.RadioButton radio_runs_prevent_double_contact_last;
+	[Widget] Gtk.Box vbox_runs_i_prevent_double_contact;
+	[Widget] Gtk.CheckButton checkbutton_runs_i_prevent_double_contact;
+	[Widget] Gtk.SpinButton spinbutton_runs_i_prevent_double_contact;
+	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_first;
+	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_average;
+	[Widget] Gtk.RadioButton radio_runs_i_prevent_double_contact_last;
 	
+	//encoder tab	
 	[Widget] Gtk.CheckButton checkbutton_encoder_propulsive;
 	[Widget] Gtk.SpinButton spin_encoder_smooth_con;
 	[Widget] Gtk.Label label_encoder_con;
-			
 	[Widget] Gtk.RadioButton radio_encoder_1RM_nonweighted;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted2;
 	[Widget] Gtk.RadioButton radio_encoder_1RM_weighted3;
-			
-	[Widget] Gtk.RadioButton radio_export_latin;
-	[Widget] Gtk.RadioButton radio_export_non_latin;
-	
-	[Widget] Gtk.RadioButton radio_graphs_translate;
-	[Widget] Gtk.RadioButton radio_graphs_no_translate;
-
-	[Widget] Gtk.RadioButton radio_use_heights_on_jump_indexes;
-	[Widget] Gtk.RadioButton radio_do_not_use_heights_on_jump_indexes;
-	
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_bestmeanpower;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_all;
 	[Widget] Gtk.RadioButton radio_encoder_auto_save_curve_none;
 
-
-//	[Widget] Gtk.Box hbox_language_row;
-//	[Widget] Gtk.Box hbox_combo_language;
-//	[Widget] Gtk.ComboBox combo_language;
-
+	//camera tab
 	[Widget] Gtk.Box hbox_combo_camera;
 	[Widget] Gtk.ComboBox combo_camera;
 
+	//language tab
+	[Widget] Gtk.Box hbox_combo_language;
+	[Widget] Gtk.ComboBox combo_language;
+	[Widget] Gtk.RadioButton radio_language_detected;
+	[Widget] Gtk.RadioButton radio_language_force;
+	[Widget] Gtk.RadioButton radio_graphs_translate;
+	[Widget] Gtk.RadioButton radio_graphs_no_translate;
+	[Widget] Gtk.Box hbox_need_restart;
+		
+	//other tab
+	[Widget] Gtk.ComboBox combo_decimals;
+	[Widget] Gtk.CheckButton checkbutton_ask_deletion;
+	[Widget] Gtk.RadioButton radio_export_latin;
+	[Widget] Gtk.RadioButton radio_export_non_latin;
+
+
 	[Widget] Gtk.Button button_accept;
 	[Widget] Gtk.Button button_cancel;
+	public Gtk.Button FakeButtonImported;
 	
 	static PreferencesWindow PreferencesWindowBox;
 	
 	private Preferences preferences; //stored to update SQL if anything changed
 	private Thread thread;
 
-	//language when window is called. If changes, then change data in sql and show 
-	//dialogMessage
-	//private string languageIni;
+	string databaseURL;
+	string databaseTempURL;
+	
+	ListStore langsStore;
 
 
 	PreferencesWindow () {
@@ -121,12 +141,11 @@ public class PreferencesWindow {
 		//put an icon to window
 		UtilGtk.IconWindow(preferences_win);
 
-		label_database.Visible = false;
-		label_database_temp.Visible = false;
-
 		//database and log files stuff
-		label_database.Text = Util.GetDatabaseDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
-		label_database_temp.Text = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		databaseURL = Util.GetDatabaseDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		databaseTempURL = Util.GetDatabaseTempDir() + System.IO.Path.DirectorySeparatorChar  + "chronojump.db";
+		
+		FakeButtonImported = new Gtk.Button();
 	}
 	
 	static public PreferencesWindow Show (Preferences preferences)
@@ -137,13 +156,9 @@ public class PreferencesWindow {
 
 		PreferencesWindowBox.preferences = preferences;
 
-		//PreferencesWindowBox.languageIni = language;
-		//if(UtilAll.IsWindows())
-		//	PreferencesWindowBox.createComboLanguage(language);
-		//else 
-			PreferencesWindowBox.hideLanguageStuff();
+		PreferencesWindowBox.createComboLanguage();
 
-			PreferencesWindowBox.createComboCamera(UtilVideo.GetVideoDevices(), preferences.videoDeviceNum);
+		PreferencesWindowBox.createComboCamera(UtilVideo.GetVideoDevices(), preferences.videoDeviceNum);
 		
 		string [] decs = {"1", "2", "3"};
 		PreferencesWindowBox.combo_decimals.Active = UtilGtk.ComboMakeActive(
@@ -209,6 +224,42 @@ public class PreferencesWindow {
 			PreferencesWindowBox.radio_speed_km.Active = true; 
 
 
+		if(preferences.runSpeedStartArrival)  
+			PreferencesWindowBox.radio_runs_speed_start_arrival.Active = true; 
+		else 
+			PreferencesWindowBox.radio_runs_speed_start_leaving.Active = true; 
+
+
+		//start of double contacts stuff ----
+		PreferencesWindowBox.checkbutton_runs_prevent_double_contact.Active = 
+			(preferences.runDoubleContactsMode != Constants.DoubleContact.NONE);
+		PreferencesWindowBox.checkbutton_runs_i_prevent_double_contact.Active = 
+			(preferences.runIDoubleContactsMode != Constants.DoubleContact.NONE);
+
+		PreferencesWindowBox.spinbutton_runs_prevent_double_contact.Value = 
+			preferences.runDoubleContactsMS;
+		PreferencesWindowBox.spinbutton_runs_i_prevent_double_contact.Value = 
+			preferences.runIDoubleContactsMS;
+			
+		if(preferences.runDoubleContactsMode != Constants.DoubleContact.NONE) {
+			if(preferences.runDoubleContactsMode == Constants.DoubleContact.FIRST)
+				PreferencesWindowBox.radio_runs_prevent_double_contact_first.Active = true;
+			else if(preferences.runDoubleContactsMode == Constants.DoubleContact.AVERAGE)
+				PreferencesWindowBox.radio_runs_prevent_double_contact_average.Active = true;
+			else // Constants.DoubleContact.LAST  DEFAULT
+				PreferencesWindowBox.radio_runs_prevent_double_contact_last.Active = true;
+		}
+		if(preferences.runIDoubleContactsMode != Constants.DoubleContact.NONE) {
+			if(preferences.runIDoubleContactsMode == Constants.DoubleContact.FIRST)
+				PreferencesWindowBox.radio_runs_i_prevent_double_contact_first.Active = true;
+			else if(preferences.runIDoubleContactsMode == Constants.DoubleContact.LAST)
+				PreferencesWindowBox.radio_runs_i_prevent_double_contact_last.Active = true;
+			else //Constants.DoubleContact.AVERAGE  DEFAULT
+				PreferencesWindowBox.radio_runs_i_prevent_double_contact_average.Active = true;
+		}
+		//---- end of double contacts stuff		
+
+
 		if(preferences.CSVExportDecimalSeparator == "COMMA")
 			PreferencesWindowBox.radio_export_latin.Active = true; 
 		else
@@ -230,11 +281,19 @@ public class PreferencesWindow {
 
 		//done here and not in glade to be shown with the decimal point of user language	
 		PreferencesWindowBox.label_encoder_con.Text = (0.7).ToString();
-		
+	
+		if(preferences.language == "")
+			PreferencesWindowBox.radio_language_detected.Active = true;
+		else
+			PreferencesWindowBox.radio_language_force.Active = true;
+
 		if(preferences.RGraphsTranslate)
 			PreferencesWindowBox.radio_graphs_translate.Active = true;
 		else
 			PreferencesWindowBox.radio_graphs_no_translate.Active = true;
+			
+		//allow signal to be called
+		PreferencesWindowBox.hbox_language_signalOn = true;
 		
 		if(preferences.useHeightsOnJumpIndexes)
 			PreferencesWindowBox.radio_use_heights_on_jump_indexes.Active = true;
@@ -267,45 +326,84 @@ public class PreferencesWindow {
 		combo_camera.Active = UtilGtk.ComboMakeActive(devices, devices[current]);
 	}
 
-	private void createComboLanguage(string myLanguageCode) {
-		/*
-		combo_language = ComboBox.NewText ();
-		UtilGtk.ComboUpdate(combo_language, Util.GetLanguagesNames(), "");
+	// ---- Language stuff
+	
+	//private void createComboLanguage(string myLanguageCode) {
+	private void createComboLanguage() {
 		
-		//combo_language.Entry.Changed += new EventHandler (on_combo_language_changed);
+		combo_language = ComboBox.NewText ();
+		fillLanguages();
 
 		hbox_combo_language.PackStart(combo_language, false, false, 0);
 		hbox_combo_language.ShowAll();
-		
-		bool found = false;
-		int count = 0;
-		foreach (string lang in Constants.Languages) {
-			if (myLanguageCode == Util.GetLanguageCode(lang)) {
-				combo_language.Active = count;
-				found = true;
-			}
-			count ++;
+	}
+
+	//from Longomatch ;)
+	//(C) Andoni Morales Alastruey
+	bool hbox_language_signalOn = false;
+	void fillLanguages () {
+		int index = 0, active = 0;
+
+		langsStore = new ListStore(typeof(string), typeof(CultureInfo));
+
+		foreach (CultureInfo lang in UtilLanguage.Languages) {
+			langsStore.AppendValues(lang.DisplayName, lang);
+			if (preferences.language != "" && lang.Name == preferences.language)
+				active = index;
+			index ++;
 		}
-		if(!found)
-			combo_language.Active = UtilGtk.ComboMakeActive(Constants.Languages, Util.GetLanguageName(Constants.LanguageDefault));
-		
-		//if(UtilAll.IsWindows())
-		//	combo_language.Sensitive = true;
-		//else 
-			combo_language.Sensitive = false;
-			*/
+		combo_language.Model = langsStore;
+		combo_language.Active = active;
+		combo_language.Changed += combo_language_changed;
 	}
+
+	private void on_radio_language_toggled (object obj, EventArgs args) {
+		hbox_combo_language.Sensitive = radio_language_force.Active;
+
+		if(hbox_language_signalOn)
+			hbox_need_restart.Visible = true;
+	}
+	private void on_radio_translate_toggled (object obj, EventArgs args) {
+		if(hbox_language_signalOn)
+			hbox_need_restart.Visible = true;
+	}
+	private	void combo_language_changed (object obj, EventArgs args) {
+		if(hbox_language_signalOn)
+			hbox_need_restart.Visible = true;
+	}
+
+
+	string getSelectedLanguage()
+	{
+		TreeIter iter;
+		CultureInfo info;
+
+		combo_language.GetActiveIter (out iter);
+		info = (CultureInfo) langsStore.GetValue (iter, 1);
+		if (info == null) {
+			return "";
+		} else {
+			return info.Name;
+		}
+	}
+
+	// ---- end of Language stuff
+
 			
-	private void hideLanguageStuff() {
-		//hbox_language_row.Hide();
-	}
-	
 	private void on_checkbutton_show_tv_tc_index_clicked (object o, EventArgs args) {
 		if(checkbutton_show_tv_tc_index.Active)
 			hbox_indexes.Show();
 		else
 			hbox_indexes.Hide();
 	}
+	
+	private void on_checkbutton_runs_prevent_double_contact_toggled (object o, EventArgs args) {
+		vbox_runs_prevent_double_contact.Visible = checkbutton_runs_prevent_double_contact.Active;
+	}
+	private void on_checkbutton_runs_i_prevent_double_contact_toggled (object o, EventArgs args) {
+		vbox_runs_i_prevent_double_contact.Visible = checkbutton_runs_i_prevent_double_contact.Active;
+	}
+
 		
 	void on_button_cancel_clicked (object o, EventArgs args)
 	{
@@ -326,8 +424,8 @@ public class PreferencesWindow {
 	
 	void on_button_db_folder_open_clicked (object o, EventArgs args)
 	{
-		System.IO.FileInfo file1 = new System.IO.FileInfo(label_database.Text); //potser cal una arrobar abans (a windows)
-		System.IO.FileInfo file2 = new System.IO.FileInfo(label_database_temp.Text); //potser cal una arrobar abans (a windows)
+		System.IO.FileInfo file1 = new System.IO.FileInfo(databaseURL); //potser cal una arrobar abans (a windows)
+		System.IO.FileInfo file2 = new System.IO.FileInfo(databaseTempURL); //potser cal una arrobar abans (a windows)
 
 		if(file1.Exists)
 			System.Diagnostics.Process.Start(Util.GetDatabaseDir()); 
@@ -336,6 +434,27 @@ public class PreferencesWindow {
 		else
 			new DialogMessage(Constants.MessageTypes.WARNING, Constants.DatabaseNotFound);
 	}
+	
+	void on_button_db_restore_clicked (object o, EventArgs args)
+	{
+		/*
+		 * TODO: problem is database stored is a chronojump.db or a folder (if images and videos were saved).
+		 * FileChooserAction only lets you use one type
+		 * In the future backup db as tgz or similar
+		 */
+
+		/*
+		fc = new Gtk.FileChooserDialog(Catalog.GetString("Restore database from:"),
+				preferences_win,
+				FileChooserAction.SelectFolder,
+				Catalog.GetString("Cancel"),ResponseType.Cancel,
+				Catalog.GetString("Restore"),ResponseType.Accept
+				);
+
+		ConfirmWindow confirmWin = ConfirmWindow.Show(Catalog.GetString("Are you sure you want to restore?"));
+		confirmWin.Button_accept.Clicked += new EventHandler(on_overwrite_file_accepted);
+		*/
+	}
 
 	void on_check_backup_multimedia_clicked(object o, EventArgs args) {
 		check_backup_encoder_tests.Active = check_backup_multimedia.Active;
@@ -376,8 +495,8 @@ public class PreferencesWindow {
 	Gtk.FileChooserDialog fc;
 	void on_button_db_backup_clicked (object o, EventArgs args)
 	{
-		System.IO.FileInfo file1 = new System.IO.FileInfo(label_database.Text); //potser cal una arrobar abans (a windows)
-		System.IO.FileInfo file2 = new System.IO.FileInfo(label_database_temp.Text); //potser cal una arrobar abans (a windows)
+		System.IO.FileInfo file1 = new System.IO.FileInfo(databaseURL); //potser cal una arrobar abans (a windows)
+		System.IO.FileInfo file2 = new System.IO.FileInfo(databaseTempURL); //potser cal una arrobar abans (a windows)
 		fileDB = "";
 
 		long length1 = 0;
@@ -390,9 +509,9 @@ public class PreferencesWindow {
 		if(length1 == 0 && length2 == 0) 
 			new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Error. Cannot find database."));
 		else if(length1 > length2)
-			fileDB = label_database.Text;
+			fileDB = databaseURL;
 		else
-			fileDB = label_database_temp.Text;
+			fileDB = databaseTempURL;
 
 		fc = new Gtk.FileChooserDialog(Catalog.GetString("Copy database to:"),
 				preferences_win,
@@ -465,6 +584,43 @@ public class PreferencesWindow {
 		
 	}
 	
+	void on_button_import_configuration_clicked (object o, EventArgs args)
+	{
+		fc = new Gtk.FileChooserDialog(Catalog.GetString("Import configuration file"),
+				preferences_win,
+				FileChooserAction.Open,
+				Catalog.GetString("Cancel"),ResponseType.Cancel,
+				Catalog.GetString("Import"),ResponseType.Accept
+				);
+		
+		fc.Filter = new FileFilter();
+		//it can handle future archives like: chronojump_config_SOME_VENDOR.txt
+		//and it will be copied to chronojump_config.txt
+		fc.Filter.AddPattern("chronojump_config*.txt");
+	
+		bool success = false;	
+		if (fc.Run() == (int)ResponseType.Accept) 
+		{
+			try {
+				File.Copy(fc.Filename, UtilAll.GetConfigFileName(), true);
+				LogB.Information("Imported configuration");
+
+				//will launch configInit() from gui/chronojump.cs
+				FakeButtonImported.Click();
+
+				success = true;
+			} catch {
+				LogB.Warning("Catched! Configuration cannot be imported");
+				new DialogMessage(Constants.MessageTypes.WARNING, Catalog.GetString("Error importing data."));
+			}
+		}
+		//Don't forget to call Destroy() or the FileChooserDialog window won't get closed.
+		fc.Destroy();
+
+		if(success)
+			new DialogMessage(Constants.MessageTypes.INFO, Catalog.GetString("Successfully imported."));
+	}
+	
 	private void on_overwrite_file_accepted(object o, EventArgs args)
 	{
 		try {
@@ -594,7 +750,85 @@ public class PreferencesWindow {
 			SqlitePreferences.Update("metersSecondsPreferred", PreferencesWindowBox.radio_speed_ms.Active.ToString(), true);
 			preferences.metersSecondsPreferred = PreferencesWindowBox.radio_speed_ms.Active;
 		}
+		
+		if( preferences.runSpeedStartArrival != PreferencesWindowBox.radio_runs_speed_start_arrival.Active ) {
+			SqlitePreferences.Update("runSpeedStartArrival", PreferencesWindowBox.radio_runs_speed_start_arrival.Active.ToString(), true);
+			preferences.runSpeedStartArrival = PreferencesWindowBox.radio_runs_speed_start_arrival.Active;
+		}
+		
+		//start of double contacts stuff ----
 
+		//1 simple runs ----
+		
+		//1.1 was FIRST or AVERAGE or LAST and now will be NONE
+		if( (preferences.runDoubleContactsMode != Constants.DoubleContact.NONE) && 
+				! PreferencesWindowBox.checkbutton_runs_prevent_double_contact.Active) 
+		{
+				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.NONE.ToString(), true);
+				preferences.runDoubleContactsMode = Constants.DoubleContact.NONE;
+		}
+		else if(PreferencesWindowBox.checkbutton_runs_prevent_double_contact.Active) 
+		{
+			//1.2 mode has changed between FIRST, AVERAGE or LAST
+			if( PreferencesWindowBox.radio_runs_prevent_double_contact_first.Active &&
+					(preferences.runDoubleContactsMode != Constants.DoubleContact.FIRST) ) {
+				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.FIRST.ToString(), true);
+				preferences.runDoubleContactsMode = Constants.DoubleContact.FIRST;
+			}
+			else if( PreferencesWindowBox.radio_runs_prevent_double_contact_average.Active &&
+					(preferences.runDoubleContactsMode != Constants.DoubleContact.AVERAGE) ) {
+				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.AVERAGE.ToString(), true);
+				preferences.runDoubleContactsMode = Constants.DoubleContact.AVERAGE;
+			}
+			else if( PreferencesWindowBox.radio_runs_prevent_double_contact_last.Active &&
+					(preferences.runDoubleContactsMode != Constants.DoubleContact.LAST) ) {
+				SqlitePreferences.Update("runDoubleContactsMode", Constants.DoubleContact.LAST.ToString(), true);
+				preferences.runDoubleContactsMode = Constants.DoubleContact.LAST;
+			}
+
+			if(preferences.runDoubleContactsMS != (int) PreferencesWindowBox.spinbutton_runs_prevent_double_contact.Value) {
+				SqlitePreferences.Update("runDoubleContactsMS", 
+						PreferencesWindowBox.spinbutton_runs_prevent_double_contact.Value.ToString(), true); //saved as string
+				preferences.runDoubleContactsMS = (int) spinbutton_runs_prevent_double_contact.Value;
+			}
+		}
+
+		//2 intervallic runs ----
+		
+		//2.1 was FIRST or AVERAGE or LAST and now will be NONE
+		if( (preferences.runIDoubleContactsMode != Constants.DoubleContact.NONE) && 
+				! PreferencesWindowBox.checkbutton_runs_i_prevent_double_contact.Active) 
+		{
+				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.NONE.ToString(), true);
+				preferences.runIDoubleContactsMode = Constants.DoubleContact.NONE;
+		}
+		else if(PreferencesWindowBox.checkbutton_runs_i_prevent_double_contact.Active) 
+		{
+			//2.2 mode has changed between FIRST, AVERAGE or LAST
+			if( PreferencesWindowBox.radio_runs_i_prevent_double_contact_first.Active &&
+					(preferences.runIDoubleContactsMode != Constants.DoubleContact.FIRST) ) {
+				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.FIRST.ToString(), true);
+				preferences.runIDoubleContactsMode = Constants.DoubleContact.FIRST;
+			}
+			else if( PreferencesWindowBox.radio_runs_i_prevent_double_contact_average.Active &&
+					(preferences.runIDoubleContactsMode != Constants.DoubleContact.AVERAGE) ) {
+				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.AVERAGE.ToString(), true);
+				preferences.runIDoubleContactsMode = Constants.DoubleContact.AVERAGE;
+			}
+			else if( PreferencesWindowBox.radio_runs_i_prevent_double_contact_last.Active &&
+					(preferences.runIDoubleContactsMode != Constants.DoubleContact.LAST) ) {
+				SqlitePreferences.Update("runIDoubleContactsMode", Constants.DoubleContact.LAST.ToString(), true);
+				preferences.runIDoubleContactsMode = Constants.DoubleContact.LAST;
+			}
+			
+			if(preferences.runIDoubleContactsMS != (int) PreferencesWindowBox.spinbutton_runs_i_prevent_double_contact.Value) {
+				SqlitePreferences.Update("runIDoubleContactsMS", 
+						PreferencesWindowBox.spinbutton_runs_i_prevent_double_contact.Value.ToString(), true); //saved as string
+				preferences.runIDoubleContactsMS = (int) spinbutton_runs_i_prevent_double_contact.Value;
+			}
+		}
+
+		//---- end of double contacts stuff
 		
 		
 		if( preferences.encoderPropulsive != PreferencesWindowBox.checkbutton_encoder_propulsive.Active ) {
@@ -624,6 +858,19 @@ public class PreferencesWindow {
 			preferences.CSVExportDecimalSeparator = "POINT";
 		}
 	
+		string selectedLanguage = getSelectedLanguage();
+
+		//if there was a language on SQL but now "detected" is selected, put "" in language on SQL
+		if(preferences.language != "" && radio_language_detected.Active) {
+			SqlitePreferences.Update("language", "", true);
+			preferences.language = "";
+		}
+		//if force a language, and SQL language is != than selected language, change language on SQL
+		else if(radio_language_force.Active && preferences.language != selectedLanguage) {
+			SqlitePreferences.Update("language", selectedLanguage, true);
+			preferences.language = selectedLanguage;
+		}
+
 
 		if( preferences.RGraphsTranslate != PreferencesWindowBox.radio_graphs_translate.Active ) {
 			SqlitePreferences.Update("RGraphsTranslate", 
@@ -665,24 +912,6 @@ public class PreferencesWindow {
 
 		Sqlite.Close();
 
-		/*
-		   if(UtilAll.IsWindows()) {
-		//if language has changed
-		if(UtilGtk.ComboGetActive(PreferencesWindowBox.combo_language) != languageIni) {
-		string myLanguage = SqlitePreferences.Select("language");
-		if ( myLanguage != null && myLanguage != "" && myLanguage != "0") {
-		//if language exists in sqlite preferences update it
-		SqlitePreferences.Update("language", Util.GetLanguageCodeFromName(UtilGtk.ComboGetActive(PreferencesWindowBox.combo_language)));
-		} else {
-		//else: create it
-		SqlitePreferences.Insert("language", Util.GetLanguageCodeFromName(UtilGtk.ComboGetActive(PreferencesWindowBox.combo_language)));
-		}
-
-		new DialogMessage(Catalog.GetString("Restart Chronojump to operate completely on your language."), true);
-		}
-		}
-		*/
-
 		PreferencesWindowBox.preferences_win.Hide();
 		PreferencesWindowBox = null;
 	}
