@@ -89,7 +89,7 @@ class SqliteEncoder : Sqlite
 			es.time + ", " + es.minHeight + ", '" + es.description + 
 			"', '" + es.status + "', '" + 
 			removeURLpath(es.videoURL) + "', '" + 
-			es.encoderConfiguration.ToString(":",true) + "', '" + 
+			es.encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.SQL) + "', '" +
 			Util.ConvertToPoint(es.future1) + "', '" + es.future2 + "', '" + es.future3 + "')";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -139,7 +139,7 @@ class SqliteEncoder : Sqlite
 				", description = '" + es.description + 
 				"', status = '" + es.status + 
 				"', videoURL = '" + removeURLpath(es.videoURL) + 
-				"', encoderConfiguration = '" + es.encoderConfiguration.ToString(":",true) + 
+				"', encoderConfiguration = '" + es.encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.SQL) +
 				"', future1 = '" + Util.ConvertToPoint(es.future1) + 
 				"', future2 = '" + es.future2 + 
 				"', future3 = '" + es.future3 + 
@@ -269,7 +269,7 @@ class SqliteEncoder : Sqlite
 			EncoderConfiguration econf = new EncoderConfiguration(
 				(Constants.EncoderConfigurationNames) 
 				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
-			econf.FromSQL(strFull);
+			econf.ReadParamsFromSQL(strFull);
 			
 			//if there's no video, will be "".
 			//if there's video, will be with full path
@@ -884,4 +884,30 @@ class SqliteEncoder : Sqlite
 		return -1;
 	}
 
+	/*
+	 * EncoderConfiguration
+	 */
+
+	//called on startup to load last encoderConfiguration
+	public static EncoderConfiguration LoadEncoderConfiguration()
+	{
+		string ecStr = SqlitePreferences.Select("encoderConfiguration", false);
+		
+		//1.5.1 and previous don't store encoderConfiguration on SqlitePreferences
+		if(ecStr == null || ecStr.Length == 0 || ecStr == "0" || ecStr == "")
+			return new EncoderConfiguration(); 
+
+		string [] ecStrFull = ecStr.Split(new char[] {':'});
+
+		//create object
+		EncoderConfiguration ec = new EncoderConfiguration(
+				(Constants.EncoderConfigurationNames) 
+				Enum.Parse(typeof(Constants.EncoderConfigurationNames), ecStrFull[0]) );
+
+		//assign the rest of params
+		ec.ReadParamsFromSQL(ecStrFull);
+
+		return ec;
+	}
+	
 }
