@@ -606,6 +606,8 @@ public class Util
 
 	public static double GetStiffness(double personMassInKg, double extraMass, double tv, double tc) 
 	{
+		//LogB.Warning("AT GetStiffness");
+		//LogB.Warning("1: " + personMassInKg.ToString() +  " 2: " + extraMass.ToString() + " 3: " + tv.ToString() + " 4: " + tc.ToString());
 		double totalMass = personMassInKg + extraMass;
 		
 		//return if mass is zero or there's no contact time
@@ -802,18 +804,14 @@ public class Util
 	}
 
 	/********** end of database paths ************/
-	
+
+	/*	
 	public static string GetChronojumpNetworksFile() {
 		return Path.Combine(
 				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
 				"Chronojump" + Path.DirectorySeparatorChar + "chronojump_networks.txt");
 	}
-	public static string GetChronojumpRaspberryFile() {
-		return Path.Combine(
-				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
-				"Chronojump" + Path.DirectorySeparatorChar + "chronojump_raspberry.txt");
-	}
-	
+	*/
 	
 
 	/********** start of multimedia paths ************/
@@ -966,6 +964,12 @@ public class Util
 	public static string GetCssDir(){
 		return GetDataDir();
 	}
+
+	//currently sounds are inside images folder	
+	public static string GetSoundsDir(){
+		return GetImagesDir();
+	}
+	
 	
 	public static void BackupDirCreateIfNeeded () {
 		string backupDir = GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
@@ -1151,70 +1155,65 @@ public class Util
 		if(volumeOn) {
 			//TODO: this try/catch still doesn't work in my laptop with sound problems
 			try {
-				switch(mySound) {
-					case Constants.SoundTypes.CAN_START:
-						System.Media.SystemSounds.Question.Play();
-						break;
-					case Constants.SoundTypes.GOOD:
-						System.Media.SystemSounds.Asterisk.Play();
-						break;
-					case Constants.SoundTypes.BAD:
-						//System.Media.SystemSounds.Beep.Play();
-						System.Media.SystemSounds.Hand.Play();
-						break;
+				if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX) 
+				{
+					string fileName = "";
+					switch(mySound) {
+						case Constants.SoundTypes.CAN_START:
+							fileName = "123804__kendallbear__kendallklap1.wav";
+							//author: kendallbear
+							//https://www.freesound.org/people/kendallbear/sounds/123804/
+							break;
+						case Constants.SoundTypes.GOOD:
+							fileName = "135936__bradwesson__collectcoin.wav";
+							//author: bradwesson
+							//https://www.freesound.org/people/bradwesson/sounds/135936/
+							break;
+						case Constants.SoundTypes.BAD:
+							fileName = "142608__autistic-lucario__error.wav";
+							//author: Autistic Lucario
+							//https://www.freesound.org/people/Autistic%20Lucario/sounds/142608/
+							break;
+					}
+							
+					fileName = Util.GetSoundsDir() + Path.DirectorySeparatorChar + fileName;
+
+					if(! File.Exists(fileName)) {
+						LogB.Warning("Cannot found this sound file: " + fileName);
+						return;
+					}
+					
+					ProcessStartInfo pinfo = new ProcessStartInfo();
+					string pBin="gst-launch-0.10";
+		
+					pinfo.FileName=pBin;
+					pinfo.Arguments = "playbin " + @"uri=file://" + fileName;
+					LogB.Information("Arguments:", pinfo.Arguments);
+					pinfo.CreateNoWindow = true;
+					pinfo.UseShellExecute = false;
+
+					Process p = new Process();
+					p.StartInfo = pinfo;
+					p.Start();
+				}
+				else {
+					switch(mySound) {
+						case Constants.SoundTypes.CAN_START:
+							System.Media.SystemSounds.Question.Play();
+							break;
+						case Constants.SoundTypes.GOOD:
+							System.Media.SystemSounds.Asterisk.Play();
+							break;
+						case Constants.SoundTypes.BAD:
+							//System.Media.SystemSounds.Beep.Play();
+							System.Media.SystemSounds.Hand.Play();
+							break;
+					}
 				}
 			} catch {}
 		}
 	}
 
-	/* LANGUAGES STUFF */
-	public static string GetLanguageCode(string languageString) {
-		string [] myStringFull = languageString.Split(new char[] {':'});
-		return myStringFull[0];
-	}
-
-	public static string GetLanguageName(string languageString) {
-		string [] myStringFull = languageString.Split(new char[] {':'});
-		return myStringFull[1];
-	}
-	
-	public static string GetLanguageNameFromCode(string languageCode) {
-		foreach (string lang in Constants.Languages) {
-			if (languageCode == GetLanguageCode(lang)) {
-				return GetLanguageName(lang);
-			}
-		}
-		//if there's an error:
-		return GetLanguageName(Constants.LanguageDefault);
-	}
-		
-	public static string GetLanguageCodeFromName(string languageName) {
-		foreach (string lang in Constants.Languages) {
-			if (languageName == GetLanguageName(lang)) {
-				return GetLanguageCode(lang);
-			}
-		}
-		//if there's an error:
-		return GetLanguageCode(Constants.LanguageDefault);
-	}
-		
-	public static string [] GetLanguagesCodes() {
-		string [] codes = new string[Constants.Languages.Length];
-		int count = 0;
-		foreach (string lang in Constants.Languages) 
-			codes[count++] = GetLanguageCode(lang);
-
-		return codes;
-	}
-		
-	public static string [] GetLanguagesNames() {
-		string [] names = new string[Constants.Languages.Length];
-		int count = 0;
-		foreach (string lang in Constants.Languages) 
-			names[count++] = GetLanguageName(lang);
-		
-		return names;
-	}
 
 	public static string GetImagePath(bool mini) {
 		string returnString = "";
